/**********************************************************************************************************************
 * \file Blinky.c
 * \copyright Copyright (C) Infineon Technologies AG 2023
 * 
 * Use of this file is subject to the terms of use agreed between (i) you or the company in which ordinary course of 
 * business you are acting and (ii) Infineon Technologies AG or its licensees. If and as long as no such terms of use
 * are agreed, use of this file is subject to following:
 * 
 * Boost Software License - Version 1.0 - August 17th, 2003
 * 
 * Permission is hereby granted, free of charge, to any person or organization obtaining a copy of the software and 
 * accompanying documentation covered by this license (the "Software") to use, reproduce, display, distribute, execute,
 * and transmit the Software, and to prepare derivative works of the Software, and to permit third-parties to whom the
 * Software is furnished to do so, all subject to the following:
 * 
 * The copyright notices in the Software and this entire statement, including the above license grant, this restriction
 * and the following disclaimer, must be included in all copies of the Software, in whole or in part, and all 
 * derivative works of the Software, unless such copies or derivative works are solely in the form of 
 * machine-executable object code generated by a source language processor.
 * 
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE 
 * COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN 
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS 
 * IN THE SOFTWARE.
 * 
 * SPDX-License-Identifier: BSL-1.0
 *********************************************************************************************************************/

/*********************************************************************************************************************/
/*-----------------------------------------------------Includes------------------------------------------------------*/
/*********************************************************************************************************************/
#include "IfxPort_PinMap.h"
#include "Port/Io/IfxPort_Io.h"

#include <stdio.h>

#include "FreeRTOS.h"
#include "task.h"

/*********************************************************************************************************************/
/*------------------------------------------------------Macros-------------------------------------------------------*/
/*********************************************************************************************************************/
#define LED_1                   IfxPort_P00_5       /* Port/Pin for LED 1                                            */
#define LED_2                   IfxPort_P00_6       /* Port/Pin for LED 2                                            */
#define BUTTON_1                IfxPort_P00_7       /* Port/Pin for BUTTION 1                                        */

#define BLINKY_PERIOD_MS        (250)               /* The period of the blinky task                                 */

/*********************************************************************************************************************/
/*---------------------------------------------Function Implementations----------------------------------------------*/
/*********************************************************************************************************************/
/* Initialize the IO ports/pins for LED1, LED2 and BUTTON1 */
static void task_init(void)
{
    /* Set input mode for the BUTTON1 pin */
    IfxPort_setPinMode(BUTTON_1.port, BUTTON_1.pinIndex, IfxPort_Mode_inputPullUp);

    /* Setup the port/pin connected to LED1 and LED2 to general output mode push-pull */
    IfxPort_setPinMode(LED_1.port, LED_1.pinIndex, IfxPort_Mode_outputPushPullGeneral);
    IfxPort_setPinMode(LED_2.port, LED_2.pinIndex, IfxPort_Mode_outputPushPullGeneral);
}

/* Task which blinks LED1 at an interval of BLINKY_PERIOD_MS and toggles LED2 each time BUTTON1 is pressed */
void task_blinky(void *arg)
{

    task_init();

    while (1)
    {
        /* Toggle LED1 state */
        IfxPort_setPinState(LED_1.port, LED_1.pinIndex, IfxPort_State_toggled);

        /* If BUTTON_1 is pressed, toggle LED_2 */
        if (IfxPort_getPinState(BUTTON_1.port, BUTTON_1.pinIndex) == 0) {
            IfxPort_setPinState(LED_2.port, LED_2.pinIndex, IfxPort_State_toggled);
        }

        /* Delay 250ms */
        vTaskDelay(pdMS_TO_TICKS(BLINKY_PERIOD_MS));

    }
}
