/**********************************************************************************************************************
 * \file serialio.h
 * \copyright Copyright (C) Infineon Technologies AG 2019
 *
 * Use of this file is subject to the terms of use agreed between (i) you or the company in which ordinary course of
 * business you are acting and (ii) Infineon Technologies AG or its licensees. If and as long as no such terms of use
 * are agreed, use of this file is subject to following:
 *
 * Boost Software License - Version 1.0 - August 17th, 2003
 *
 * Permission is hereby granted, free of charge, to any person or organization obtaining a copy of the software and
 * accompanying documentation covered by this license (the "Software") to use, reproduce, display, distribute, execute,
 * and transmit the Software, and to prepare derivative works of the Software, and to permit third-parties to whom the
 * Software is furnished to do so, all subject to the following:
 *
 * The copyright notices in the Software and this entire statement, including the above license grant, this restriction
 * and the following disclaimer, must be included in all copies of the Software, in whole or in part, and all
 * derivative works of the Software, unless such copies or derivative works are solely in the form of
 * machine-executable object code generated by a source language processor.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 * WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE, TITLE AND NON-INFRINGEMENT. IN NO EVENT SHALL THE
 * COPYRIGHT HOLDERS OR ANYONE DISTRIBUTING THE SOFTWARE BE LIABLE FOR ANY DAMAGES OR OTHER LIABILITY, WHETHER IN
 * CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
 * IN THE SOFTWARE.
 * 
 * SPDX-License-Identifier: BSL-1.0
 *********************************************************************************************************************/

/*******************************************************************************
 **                             Author(s) Identity                             **
 ********************************************************************************
 ** Initials     Name                                                          **
 ** ---------------------------------------------------------------------------**
 ** RS           Ronny Schulze                                                 **
 ** DM           Daniel Mysliwitz                                              **
 ** MV           Matteo Vitturi                                                **
 *******************************************************************************/

/*******************************************************************************
 **                Revision Control History of serialio lib                    **
 ********************************************************************************
 ** V0.1.0: 2021-10-07, RS:   Initial version                                  **
 ** V0.1.1: 2021-11-24, DM:   adding _io_putc() to make printf() functional    **
 **                           with Tasking compiler                            **
 ** V0.1.2: 2021-12-21, MV:   Reworked initialization function using standard  **
 **                           iLLD functions to initialize the module          **
 ** V0.1.3: 2022-02-07, DM:   sync. the ASC init. to the VCOM example          **
 **                           adapt the README documentation                   **
 *******************************************************************************/

#ifndef SERIALIO_H
#define SERIALIO_H

/*********************************************************************************************************************/
/*-----------------------------------------------------Includes------------------------------------------------------*/
/*********************************************************************************************************************/
#include <stdio.h>
#include <inttypes.h>
#include "Asclin/Asc/IfxAsclin_Asc.h"
#include "Asclin/Std/IfxAsclin.h"

/*********************************************************************************************************************/
/*------------------------------------------------------Macros-------------------------------------------------------*/
/*********************************************************************************************************************/
#define SERIALIO_STRLEN 1024

#define PRINT_STRING( x )    fprintf(stderr, x)
#define PRINTF_STRING(...) { do {sprintf(SERIALIO.str, __VA_ARGS__); PRINT_STRING(SERIALIO.str);} while(0);}

/*********************************************************************************************************************/
/*--------------------------------------------------Data Structures--------------------------------------------------*/
/*********************************************************************************************************************/
typedef struct SERIALIO
{
    Ifx_ASCLIN *const asclin;
    IfxAsclin_Tx_Out *const tx_pin;
    IfxAsclin_Rx_In *const rx_pin;
    char str[SERIALIO_STRLEN];
} SERIALIO_t;

extern SERIALIO_t SERIALIO;

#ifdef __cplusplus
extern "C" {
#endif /* __cplusplus */

/*********************************************************************************************************************/
/*-----------------------------------------------Function Prototypes-------------------------------------------------*/
/*********************************************************************************************************************/
void SERIALIO_Init (sint32 baudrate);

#ifdef __cplusplus
}
#endif /* __cplusplus */

#endif /* SERIALIO_H */
