/********************************************************************
 * Copyright (C) 2022 Texas Instruments Incorporated.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *  Name        : cslr_main_sec_mmr.h
*/
#ifndef CSLR_MAIN_SEC_MMR_H_
#define CSLR_MAIN_SEC_MMR_H_

#ifdef __cplusplus
extern "C"
{
#endif
#include <drivers/hw_include/cslr.h>
#include <stdint.h>

/**************************************************************************
* Module Base Offset Values
**************************************************************************/

#define CSL_MAIN_SEC_MMR_CFG0_REGS_BASE                                   (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG2_REGS_BASE                                   (0x00000000U)


/**************************************************************************
* Hardware Region  : MMRs in region 0
**************************************************************************/


/**************************************************************************
* Register Overlay Structure
**************************************************************************/

typedef struct {
    volatile uint32_t PID;                       /* PID register */
    volatile uint8_t  Resv_32[28];
    volatile uint32_t CLSTR0_DEF;
    volatile uint8_t  Resv_64[28];
    volatile uint32_t CLSTR0_CFG;
    volatile uint8_t  Resv_128[60];
    volatile uint32_t CLSTR0_PMCTRL;
    volatile uint8_t  Resv_144[12];
    volatile uint32_t CLSTR0_PMSTAT;
    volatile uint8_t  Resv_256[108];
    volatile uint32_t CLSTR0_CORE0_CFG;
    volatile uint8_t  Resv_272[12];
    volatile uint32_t CLSTR0_CORE0_BOOTVECT_LO;
    volatile uint32_t CLSTR0_CORE0_BOOTVECT_HI;
    volatile uint8_t  Resv_288[8];
    volatile uint32_t CLSTR0_CORE0_PMCTRL;
    volatile uint8_t  Resv_304[12];
    volatile uint32_t CLSTR0_CORE0_PMSTAT;
    volatile uint8_t  Resv_384[76];
    volatile uint32_t CLSTR0_CORE1_CFG;
    volatile uint8_t  Resv_400[12];
    volatile uint32_t CLSTR0_CORE1_BOOTVECT_LO;
    volatile uint32_t CLSTR0_CORE1_BOOTVECT_HI;
    volatile uint8_t  Resv_416[8];
    volatile uint32_t CLSTR0_CORE1_PMCTRL;
    volatile uint8_t  Resv_432[12];
    volatile uint32_t CLSTR0_CORE1_PMSTAT;
    volatile uint8_t  Resv_4128[3692];
    volatile uint32_t CLSTR1_DEF;
    volatile uint8_t  Resv_4160[28];
    volatile uint32_t CLSTR1_CFG;
    volatile uint8_t  Resv_4224[60];
    volatile uint32_t CLSTR1_PMCTRL;
    volatile uint8_t  Resv_4240[12];
    volatile uint32_t CLSTR1_PMSTAT;
    volatile uint8_t  Resv_4352[108];
    volatile uint32_t CLSTR1_CORE0_CFG;
    volatile uint8_t  Resv_4368[12];
    volatile uint32_t CLSTR1_CORE0_BOOTVECT_LO;
    volatile uint32_t CLSTR1_CORE0_BOOTVECT_HI;
    volatile uint8_t  Resv_4384[8];
    volatile uint32_t CLSTR1_CORE0_PMCTRL;
    volatile uint8_t  Resv_4400[12];
    volatile uint32_t CLSTR1_CORE0_PMSTAT;
    volatile uint8_t  Resv_4480[76];
    volatile uint32_t CLSTR1_CORE1_CFG;
    volatile uint8_t  Resv_4496[12];
    volatile uint32_t CLSTR1_CORE1_BOOTVECT_LO;
    volatile uint32_t CLSTR1_CORE1_BOOTVECT_HI;
    volatile uint8_t  Resv_4512[8];
    volatile uint32_t CLSTR1_CORE1_PMCTRL;
    volatile uint8_t  Resv_4528[12];
    volatile uint32_t CLSTR1_CORE1_PMSTAT;
    volatile uint8_t  Resv_36896[32364];
    volatile uint32_t CLSTR9_DEF;
    volatile uint8_t  Resv_36928[28];
    volatile uint32_t CLSTR9_CFG;
    volatile uint8_t  Resv_36992[60];
    volatile uint32_t CLSTR9_PMCTRL;
    volatile uint8_t  Resv_37008[12];
    volatile uint32_t CLSTR9_PMSTAT;
    volatile uint8_t  Resv_37120[108];
    volatile uint32_t CLSTR9_CORE0_CFG;
    volatile uint8_t  Resv_37136[12];
    volatile uint32_t CLSTR9_CORE0_BOOTVECT_LO;
    volatile uint32_t CLSTR9_CORE0_BOOTVECT_HI;
    volatile uint8_t  Resv_37152[8];
    volatile uint32_t CLSTR9_CORE0_PMCTRL;
    volatile uint8_t  Resv_37168[12];
    volatile uint32_t CLSTR9_CORE0_PMSTAT;
    volatile uint8_t  Resv_37248[76];
    volatile uint32_t CLSTR9_CORE1_CFG;
    volatile uint8_t  Resv_37264[12];
    volatile uint32_t CLSTR9_CORE1_BOOTVECT_LO;
    volatile uint32_t CLSTR9_CORE1_BOOTVECT_HI;
    volatile uint8_t  Resv_37280[8];
    volatile uint32_t CLSTR9_CORE1_PMCTRL;
    volatile uint8_t  Resv_37296[12];
    volatile uint32_t CLSTR9_CORE1_PMSTAT;
    volatile uint8_t  Resv_65568[28268];
    volatile uint32_t CLSTR16_DEF;
    volatile uint8_t  Resv_65600[28];
    volatile uint32_t CLSTR16_CFG;
    volatile uint8_t  Resv_65664[60];
    volatile uint32_t CLSTR16_PMCTRL;
    volatile uint8_t  Resv_65680[12];
    volatile uint32_t CLSTR16_PMSTAT;
    volatile uint8_t  Resv_65792[108];
    volatile uint32_t CLSTR16_CORE0_CFG;
    volatile uint8_t  Resv_65808[12];
    volatile uint32_t CLSTR16_CORE0_BOOTVECT_LO;
    volatile uint32_t CLSTR16_CORE0_BOOTVECT_HI;
    volatile uint8_t  Resv_65824[8];
    volatile uint32_t CLSTR16_CORE0_PMCTRL;
    volatile uint8_t  Resv_65840[12];
    volatile uint32_t CLSTR16_CORE0_PMSTAT;
    volatile uint8_t  Resv_65920[76];
    volatile uint32_t CLSTR16_CORE1_CFG;
    volatile uint8_t  Resv_65936[12];
    volatile uint32_t CLSTR16_CORE1_BOOTVECT_LO;
    volatile uint32_t CLSTR16_CORE1_BOOTVECT_HI;
    volatile uint8_t  Resv_65952[8];
    volatile uint32_t CLSTR16_CORE1_PMCTRL;
    volatile uint8_t  Resv_65968[12];
    volatile uint32_t CLSTR16_CORE1_PMSTAT;
    volatile uint8_t  Resv_98312[32340];
    volatile uint32_t GIC_CONFIG;
} CSL_main_sec_mmr_cfg0Regs;


/**************************************************************************
* Register Macros
**************************************************************************/

#define CSL_MAIN_SEC_MMR_CFG0_PID                                         (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_DEF                                  (0x00000020U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG                                  (0x00000040U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_PMCTRL                               (0x00000080U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_PMSTAT                               (0x00000090U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG                            (0x00000100U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_BOOTVECT_LO                    (0x00000110U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_BOOTVECT_HI                    (0x00000114U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMCTRL                         (0x00000120U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMSTAT                         (0x00000130U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG                            (0x00000180U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_BOOTVECT_LO                    (0x00000190U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_BOOTVECT_HI                    (0x00000194U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMCTRL                         (0x000001A0U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMSTAT                         (0x000001B0U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_DEF                                  (0x00001020U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG                                  (0x00001040U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_PMCTRL                               (0x00001080U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_PMSTAT                               (0x00001090U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG                            (0x00001100U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_BOOTVECT_LO                    (0x00001110U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_BOOTVECT_HI                    (0x00001114U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMCTRL                         (0x00001120U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMSTAT                         (0x00001130U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG                            (0x00001180U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_BOOTVECT_LO                    (0x00001190U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_BOOTVECT_HI                    (0x00001194U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMCTRL                         (0x000011A0U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMSTAT                         (0x000011B0U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_DEF                                  (0x00009020U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG                                  (0x00009040U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL                               (0x00009080U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT                               (0x00009090U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_CFG                            (0x00009100U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_BOOTVECT_LO                    (0x00009110U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_BOOTVECT_HI                    (0x00009114U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_PMCTRL                         (0x00009120U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_PMSTAT                         (0x00009130U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_CFG                            (0x00009180U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_BOOTVECT_LO                    (0x00009190U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_BOOTVECT_HI                    (0x00009194U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_PMCTRL                         (0x000091A0U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_PMSTAT                         (0x000091B0U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_DEF                                 (0x00010020U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CFG                                 (0x00010040U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_PMCTRL                              (0x00010080U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_PMSTAT                              (0x00010090U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_CFG                           (0x00010100U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_BOOTVECT_LO                   (0x00010110U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_BOOTVECT_HI                   (0x00010114U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_PMCTRL                        (0x00010120U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_PMSTAT                        (0x00010130U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_CFG                           (0x00010180U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_BOOTVECT_LO                   (0x00010190U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_BOOTVECT_HI                   (0x00010194U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_PMCTRL                        (0x000101A0U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_PMSTAT                        (0x000101B0U)
#define CSL_MAIN_SEC_MMR_CFG0_GIC_CONFIG                                  (0x00018008U)

/**************************************************************************
* Field Definition Macros
**************************************************************************/


/* PID */

#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MINOR_MASK                          (0x0000003FU)
#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MINOR_SHIFT                         (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MINOR_MAX                           (0x0000003FU)

#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_CUSTOM_MASK                         (0x000000C0U)
#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_CUSTOM_SHIFT                        (0x00000006U)
#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_CUSTOM_MAX                          (0x00000003U)

#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MAJOR_MASK                          (0x00000700U)
#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MAJOR_SHIFT                         (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MAJOR_MAX                           (0x00000007U)

#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MISC_MASK                           (0x0000F800U)
#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MISC_SHIFT                          (0x0000000BU)
#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MISC_MAX                            (0x0000001FU)

#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MSB16_MASK                          (0xFFFF0000U)
#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MSB16_SHIFT                         (0x00000010U)
#define CSL_MAIN_SEC_MMR_CFG0_PID_PID_MSB16_MAX                           (0x0000FFFFU)

/* CLSTR0_DEF */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_DEF_ARM_CORE_TYPE_MASK               (0x000000FFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_DEF_ARM_CORE_TYPE_SHIFT              (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_DEF_ARM_CORE_TYPE_MAX                (0x000000FFU)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_DEF_DSP_CORE_TYPE_MASK               (0x0000FF00U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_DEF_DSP_CORE_TYPE_SHIFT              (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_DEF_DSP_CORE_TYPE_MAX                (0x000000FFU)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_DEF_CORE_NUM_MASK                    (0x00070000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_DEF_CORE_NUM_SHIFT                   (0x00000010U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_DEF_CORE_NUM_MAX                     (0x00000007U)

/* CLSTR0_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_LOCKSTEP_MASK                    (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_LOCKSTEP_SHIFT                   (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_LOCKSTEP_MAX                     (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_TEINIT_MASK                      (0x00000002U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_TEINIT_SHIFT                     (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_TEINIT_MAX                       (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_DBG_NO_CLKSTOP_MASK              (0x00000004U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_DBG_NO_CLKSTOP_SHIFT             (0x00000002U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_DBG_NO_CLKSTOP_MAX               (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_LOCKSTEP_EN_MASK                 (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_LOCKSTEP_EN_SHIFT                (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_LOCKSTEP_EN_MAX                  (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_MEM_INIT_DIS_MASK                (0x00000010U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_MEM_INIT_DIS_SHIFT               (0x00000004U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_MEM_INIT_DIS_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_SINGLE_CORE_MASK                 (0x00000020U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_SINGLE_CORE_SHIFT                (0x00000005U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_SINGLE_CORE_MAX                  (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_SINGLE_CORE_ONLY_MASK            (0x00000040U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_SINGLE_CORE_ONLY_SHIFT           (0x00000006U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_SINGLE_CORE_ONLY_MAX             (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_CLSTR_CFG_RSVD_MASK              (0xFFFFFF80U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_CLSTR_CFG_RSVD_SHIFT             (0x00000007U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CFG_CLSTR_CFG_RSVD_MAX               (0x01FFFFFFU)

/* CLSTR0_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_PMCTRL_RESERVED_MASK                 (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_PMCTRL_RESERVED_SHIFT                (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_PMCTRL_RESERVED_MAX                  (0xFFFFFFFFU)

/* CLSTR0_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_PMSTAT_RESERVED_MASK                 (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_PMSTAT_RESERVED_SHIFT                (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_PMSTAT_RESERVED_MAX                  (0xFFFFFFFFU)

/* CLSTR0_CORE0_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_ATCM_EN_MASK               (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_ATCM_EN_SHIFT              (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_ATCM_EN_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_BTCM_EN_MASK               (0x00000080U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_BTCM_EN_SHIFT              (0x00000007U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_BTCM_EN_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_TCM_RSTBASE_MASK           (0x00000800U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_TCM_RSTBASE_SHIFT          (0x0000000BU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_TCM_RSTBASE_MAX            (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_NMFI_EN_MASK               (0x00008000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_NMFI_EN_SHIFT              (0x0000000FU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_CFG_NMFI_EN_MAX                (0x00000001U)

/* CLSTR0_CORE0_BOOTVECT_LO */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_BOOTVECT_LO_VECT_ADDR_MASK     (0xFFFFFF80U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_BOOTVECT_LO_VECT_ADDR_SHIFT    (0x00000007U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_BOOTVECT_LO_VECT_ADDR_MAX      (0x01FFFFFFU)

/* CLSTR0_CORE0_BOOTVECT_HI */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_BOOTVECT_HI_VECT_ADDR_MASK     (0x0000FFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_BOOTVECT_HI_VECT_ADDR_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_BOOTVECT_HI_VECT_ADDR_MAX      (0x0000FFFFU)

/* CLSTR0_CORE0_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMCTRL_CORE_HALT_MASK          (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMCTRL_CORE_HALT_SHIFT         (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMCTRL_CORE_HALT_MAX           (0x00000001U)

/* CLSTR0_CORE0_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMSTAT_WFI_MASK                (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMSTAT_WFI_SHIFT               (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMSTAT_WFI_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMSTAT_WFE_MASK                (0x00000002U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMSTAT_WFE_SHIFT               (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMSTAT_WFE_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMSTAT_CLK_GATE_MASK           (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMSTAT_CLK_GATE_SHIFT          (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE0_PMSTAT_CLK_GATE_MAX            (0x00000001U)

/* CLSTR0_CORE1_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_ATCM_EN_MASK               (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_ATCM_EN_SHIFT              (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_ATCM_EN_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_BTCM_EN_MASK               (0x00000080U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_BTCM_EN_SHIFT              (0x00000007U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_BTCM_EN_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_TCM_RSTBASE_MASK           (0x00000800U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_TCM_RSTBASE_SHIFT          (0x0000000BU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_TCM_RSTBASE_MAX            (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_NMFI_EN_MASK               (0x00008000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_NMFI_EN_SHIFT              (0x0000000FU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_CFG_NMFI_EN_MAX                (0x00000001U)

/* CLSTR0_CORE1_BOOTVECT_LO */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_BOOTVECT_LO_VECT_ADDR_MASK     (0xFFFFFF80U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_BOOTVECT_LO_VECT_ADDR_SHIFT    (0x00000007U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_BOOTVECT_LO_VECT_ADDR_MAX      (0x01FFFFFFU)

/* CLSTR0_CORE1_BOOTVECT_HI */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_BOOTVECT_HI_VECT_ADDR_MASK     (0x0000FFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_BOOTVECT_HI_VECT_ADDR_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_BOOTVECT_HI_VECT_ADDR_MAX      (0x0000FFFFU)

/* CLSTR0_CORE1_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMCTRL_CORE_HALT_MASK          (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMCTRL_CORE_HALT_SHIFT         (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMCTRL_CORE_HALT_MAX           (0x00000001U)

/* CLSTR0_CORE1_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMSTAT_WFI_MASK                (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMSTAT_WFI_SHIFT               (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMSTAT_WFI_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMSTAT_WFE_MASK                (0x00000002U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMSTAT_WFE_SHIFT               (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMSTAT_WFE_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMSTAT_CLK_GATE_MASK           (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMSTAT_CLK_GATE_SHIFT          (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR0_CORE1_PMSTAT_CLK_GATE_MAX            (0x00000001U)

/* CLSTR1_DEF */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_DEF_ARM_CORE_TYPE_MASK               (0x000000FFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_DEF_ARM_CORE_TYPE_SHIFT              (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_DEF_ARM_CORE_TYPE_MAX                (0x000000FFU)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_DEF_DSP_CORE_TYPE_MASK               (0x0000FF00U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_DEF_DSP_CORE_TYPE_SHIFT              (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_DEF_DSP_CORE_TYPE_MAX                (0x000000FFU)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_DEF_CORE_NUM_MASK                    (0x00070000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_DEF_CORE_NUM_SHIFT                   (0x00000010U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_DEF_CORE_NUM_MAX                     (0x00000007U)

/* CLSTR1_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_LOCKSTEP_MASK                    (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_LOCKSTEP_SHIFT                   (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_LOCKSTEP_MAX                     (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_TEINIT_MASK                      (0x00000002U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_TEINIT_SHIFT                     (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_TEINIT_MAX                       (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_DBG_NO_CLKSTOP_MASK              (0x00000004U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_DBG_NO_CLKSTOP_SHIFT             (0x00000002U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_DBG_NO_CLKSTOP_MAX               (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_LOCKSTEP_EN_MASK                 (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_LOCKSTEP_EN_SHIFT                (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_LOCKSTEP_EN_MAX                  (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_MEM_INIT_DIS_MASK                (0x00000010U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_MEM_INIT_DIS_SHIFT               (0x00000004U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_MEM_INIT_DIS_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_SINGLE_CORE_MASK                 (0x00000020U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_SINGLE_CORE_SHIFT                (0x00000005U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_SINGLE_CORE_MAX                  (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_SINGLE_CORE_ONLY_MASK            (0x00000040U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_SINGLE_CORE_ONLY_SHIFT           (0x00000006U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_SINGLE_CORE_ONLY_MAX             (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_CLSTR_CFG_RSVD_MASK              (0xFFFFFF80U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_CLSTR_CFG_RSVD_SHIFT             (0x00000007U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CFG_CLSTR_CFG_RSVD_MAX               (0x01FFFFFFU)

/* CLSTR1_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_PMCTRL_RESERVED_MASK                 (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_PMCTRL_RESERVED_SHIFT                (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_PMCTRL_RESERVED_MAX                  (0xFFFFFFFFU)

/* CLSTR1_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_PMSTAT_RESERVED_MASK                 (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_PMSTAT_RESERVED_SHIFT                (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_PMSTAT_RESERVED_MAX                  (0xFFFFFFFFU)

/* CLSTR1_CORE0_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_ATCM_EN_MASK               (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_ATCM_EN_SHIFT              (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_ATCM_EN_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_BTCM_EN_MASK               (0x00000080U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_BTCM_EN_SHIFT              (0x00000007U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_BTCM_EN_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_TCM_RSTBASE_MASK           (0x00000800U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_TCM_RSTBASE_SHIFT          (0x0000000BU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_TCM_RSTBASE_MAX            (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_NMFI_EN_MASK               (0x00008000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_NMFI_EN_SHIFT              (0x0000000FU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_CFG_NMFI_EN_MAX                (0x00000001U)

/* CLSTR1_CORE0_BOOTVECT_LO */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_BOOTVECT_LO_VECT_ADDR_MASK     (0xFFFFFF80U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_BOOTVECT_LO_VECT_ADDR_SHIFT    (0x00000007U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_BOOTVECT_LO_VECT_ADDR_MAX      (0x01FFFFFFU)

/* CLSTR1_CORE0_BOOTVECT_HI */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_BOOTVECT_HI_VECT_ADDR_MASK     (0x0000FFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_BOOTVECT_HI_VECT_ADDR_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_BOOTVECT_HI_VECT_ADDR_MAX      (0x0000FFFFU)

/* CLSTR1_CORE0_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMCTRL_CORE_HALT_MASK          (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMCTRL_CORE_HALT_SHIFT         (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMCTRL_CORE_HALT_MAX           (0x00000001U)

/* CLSTR1_CORE0_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMSTAT_WFI_MASK                (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMSTAT_WFI_SHIFT               (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMSTAT_WFI_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMSTAT_WFE_MASK                (0x00000002U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMSTAT_WFE_SHIFT               (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMSTAT_WFE_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMSTAT_CLK_GATE_MASK           (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMSTAT_CLK_GATE_SHIFT          (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE0_PMSTAT_CLK_GATE_MAX            (0x00000001U)

/* CLSTR1_CORE1_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_ATCM_EN_MASK               (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_ATCM_EN_SHIFT              (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_ATCM_EN_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_BTCM_EN_MASK               (0x00000080U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_BTCM_EN_SHIFT              (0x00000007U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_BTCM_EN_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_TCM_RSTBASE_MASK           (0x00000800U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_TCM_RSTBASE_SHIFT          (0x0000000BU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_TCM_RSTBASE_MAX            (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_NMFI_EN_MASK               (0x00008000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_NMFI_EN_SHIFT              (0x0000000FU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_CFG_NMFI_EN_MAX                (0x00000001U)

/* CLSTR1_CORE1_BOOTVECT_LO */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_BOOTVECT_LO_VECT_ADDR_MASK     (0xFFFFFF80U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_BOOTVECT_LO_VECT_ADDR_SHIFT    (0x00000007U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_BOOTVECT_LO_VECT_ADDR_MAX      (0x01FFFFFFU)

/* CLSTR1_CORE1_BOOTVECT_HI */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_BOOTVECT_HI_VECT_ADDR_MASK     (0x0000FFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_BOOTVECT_HI_VECT_ADDR_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_BOOTVECT_HI_VECT_ADDR_MAX      (0x0000FFFFU)

/* CLSTR1_CORE1_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMCTRL_CORE_HALT_MASK          (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMCTRL_CORE_HALT_SHIFT         (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMCTRL_CORE_HALT_MAX           (0x00000001U)

/* CLSTR1_CORE1_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMSTAT_WFI_MASK                (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMSTAT_WFI_SHIFT               (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMSTAT_WFI_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMSTAT_WFE_MASK                (0x00000002U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMSTAT_WFE_SHIFT               (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMSTAT_WFE_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMSTAT_CLK_GATE_MASK           (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMSTAT_CLK_GATE_SHIFT          (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR1_CORE1_PMSTAT_CLK_GATE_MAX            (0x00000001U)

/* CLSTR9_DEF */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_DEF_ARM_CORE_TYPE_MASK               (0x000000FFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_DEF_ARM_CORE_TYPE_SHIFT              (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_DEF_ARM_CORE_TYPE_MAX                (0x000000FFU)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_DEF_DSP_CORE_TYPE_MASK               (0x0000FF00U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_DEF_DSP_CORE_TYPE_SHIFT              (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_DEF_DSP_CORE_TYPE_MAX                (0x000000FFU)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_DEF_CORE_NUM_MASK                    (0x00030000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_DEF_CORE_NUM_SHIFT                   (0x00000010U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_DEF_CORE_NUM_MAX                     (0x00000003U)

/* CLSTR9_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_AARCH0_MASK                      (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_AARCH0_SHIFT                     (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_AARCH0_MAX                       (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_AARCH1_MASK                      (0x00000002U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_AARCH1_SHIFT                     (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_AARCH1_MAX                       (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CONFIG_TE0_MASK                  (0x00000010U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CONFIG_TE0_SHIFT                 (0x00000004U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CONFIG_TE0_MAX                   (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CONFIG_TE1_MASK                  (0x00000020U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CONFIG_TE1_SHIFT                 (0x00000005U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CONFIG_TE1_MAX                   (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CP15_DISABLE0_MASK               (0x00000100U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CP15_DISABLE0_SHIFT              (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CP15_DISABLE0_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CP15_DISABLE1_MASK               (0x00000200U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CP15_DISABLE1_SHIFT              (0x00000009U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CFG_CP15_DISABLE1_MAX                (0x00000001U)

/* CLSTR9_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_ACINACTM_MASK                 (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_ACINACTM_SHIFT                (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_ACINACTM_MAX                  (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_AINACTS_MASK                  (0x00000002U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_AINACTS_SHIFT                 (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_AINACTS_MAX                   (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_L2_FLUSHREQ_MASK              (0x00000020U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_L2_FLUSHREQ_SHIFT             (0x00000005U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_L2_FLUSHREQ_MAX               (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_CLREXMONREQ_MASK              (0x00000040U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_CLREXMONREQ_SHIFT             (0x00000006U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_CLREXMONREQ_MAX               (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_DBGL1RSTDISABLE_MASK          (0x00000080U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_DBGL1RSTDISABLE_SHIFT         (0x00000007U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_DBGL1RSTDISABLE_MAX           (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_DBGPWRDUP0_MASK               (0x00000100U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_DBGPWRDUP0_SHIFT              (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_DBGPWRDUP0_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_DBGPWRDUP1_MASK               (0x00000200U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_DBGPWRDUP1_SHIFT              (0x00000009U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_DBGPWRDUP1_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_L2RSTDISABLE_MASK             (0x00001000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_L2RSTDISABLE_SHIFT            (0x0000000CU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMCTRL_L2RSTDISABLE_MAX              (0x00000001U)

/* CLSTR9_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE0_WFI_MASK                (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE0_WFI_SHIFT               (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE0_WFI_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE1_WFI_MASK                (0x00000002U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE1_WFI_SHIFT               (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE1_WFI_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE0_WFE_MASK                (0x00000010U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE0_WFE_SHIFT               (0x00000004U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE0_WFE_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE1_WFE_MASK                (0x00000020U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE1_WFE_SHIFT               (0x00000005U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE1_WFE_MAX                 (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE0_SMPEN_MASK              (0x00000100U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE0_SMPEN_SHIFT             (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE0_SMPEN_MAX               (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE1_SMPEN_MASK              (0x00000200U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE1_SMPEN_SHIFT             (0x00000009U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CORE1_SMPEN_MAX               (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_L2_HW_FLUSH_DONE_MASK         (0x00001000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_L2_HW_FLUSH_DONE_SHIFT        (0x0000000CU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_L2_HW_FLUSH_DONE_MAX          (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_STANDBY_WFI_L2_MASK           (0x00002000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_STANDBY_WFI_L2_SHIFT          (0x0000000DU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_STANDBY_WFI_L2_MAX            (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CLREXMONACK_MASK              (0x00004000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CLREXMONACK_SHIFT             (0x0000000EU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_PMSTAT_CLREXMONACK_MAX               (0x00000001U)

/* CLSTR9_CORE0_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_CFG_RESERVED_MASK              (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_CFG_RESERVED_SHIFT             (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_CFG_RESERVED_MAX               (0xFFFFFFFFU)

/* CLSTR9_CORE0_BOOTVECT_LO */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_BOOTVECT_LO_VECT_ADDR_MASK     (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_BOOTVECT_LO_VECT_ADDR_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_BOOTVECT_LO_VECT_ADDR_MAX      (0xFFFFFFFFU)

/* CLSTR9_CORE0_BOOTVECT_HI */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_BOOTVECT_HI_VECT_ADDR_MASK     (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_BOOTVECT_HI_VECT_ADDR_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_BOOTVECT_HI_VECT_ADDR_MAX      (0x00000003U)

/* CLSTR9_CORE0_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_PMCTRL_RESERVED_MASK           (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_PMCTRL_RESERVED_SHIFT          (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_PMCTRL_RESERVED_MAX            (0xFFFFFFFFU)

/* CLSTR9_CORE0_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_PMSTAT_RESERVED_MASK           (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_PMSTAT_RESERVED_SHIFT          (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE0_PMSTAT_RESERVED_MAX            (0xFFFFFFFFU)

/* CLSTR9_CORE1_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_CFG_RESERVED_MASK              (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_CFG_RESERVED_SHIFT             (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_CFG_RESERVED_MAX               (0xFFFFFFFFU)

/* CLSTR9_CORE1_BOOTVECT_LO */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_BOOTVECT_LO_VECT_ADDR_MASK     (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_BOOTVECT_LO_VECT_ADDR_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_BOOTVECT_LO_VECT_ADDR_MAX      (0xFFFFFFFFU)

/* CLSTR9_CORE1_BOOTVECT_HI */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_BOOTVECT_HI_VECT_ADDR_MASK     (0x00000003U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_BOOTVECT_HI_VECT_ADDR_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_BOOTVECT_HI_VECT_ADDR_MAX      (0x00000003U)

/* CLSTR9_CORE1_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_PMCTRL_RESERVED_MASK           (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_PMCTRL_RESERVED_SHIFT          (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_PMCTRL_RESERVED_MAX            (0xFFFFFFFFU)

/* CLSTR9_CORE1_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_PMSTAT_RESERVED_MASK           (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_PMSTAT_RESERVED_SHIFT          (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR9_CORE1_PMSTAT_RESERVED_MAX            (0xFFFFFFFFU)

/* CLSTR16_DEF */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_DEF_ARM_CORE_TYPE_MASK              (0x000000FFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_DEF_ARM_CORE_TYPE_SHIFT             (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_DEF_ARM_CORE_TYPE_MAX               (0x000000FFU)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_DEF_DSP_CORE_TYPE_MASK              (0x0000FF00U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_DEF_DSP_CORE_TYPE_SHIFT             (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_DEF_DSP_CORE_TYPE_MAX               (0x000000FFU)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_DEF_CORE_NUM_MASK                   (0x00070000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_DEF_CORE_NUM_SHIFT                  (0x00000010U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_DEF_CORE_NUM_MAX                    (0x00000007U)

/* CLSTR16_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CFG_RESERVED_MASK                   (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CFG_RESERVED_SHIFT                  (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CFG_RESERVED_MAX                    (0xFFFFFFFFU)

/* CLSTR16_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_PMCTRL_RESERVED_MASK                (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_PMCTRL_RESERVED_SHIFT               (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_PMCTRL_RESERVED_MAX                 (0xFFFFFFFFU)

/* CLSTR16_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_PMSTAT_RESERVED_MASK                (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_PMSTAT_RESERVED_SHIFT               (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_PMSTAT_RESERVED_MAX                 (0xFFFFFFFFU)

/* CLSTR16_CORE0_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_CFG_RESERVED_MASK             (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_CFG_RESERVED_SHIFT            (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_CFG_RESERVED_MAX              (0xFFFFFFFFU)

/* CLSTR16_CORE0_BOOTVECT_LO */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_BOOTVECT_LO_RESERVED_MASK     (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_BOOTVECT_LO_RESERVED_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_BOOTVECT_LO_RESERVED_MAX      (0xFFFFFFFFU)

/* CLSTR16_CORE0_BOOTVECT_HI */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_BOOTVECT_HI_RESERVED_MASK     (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_BOOTVECT_HI_RESERVED_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_BOOTVECT_HI_RESERVED_MAX      (0xFFFFFFFFU)

/* CLSTR16_CORE0_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_PMCTRL_RESERVED_MASK          (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_PMCTRL_RESERVED_SHIFT         (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_PMCTRL_RESERVED_MAX           (0xFFFFFFFFU)

/* CLSTR16_CORE0_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_PMSTAT_WFI_MASK               (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_PMSTAT_WFI_SHIFT              (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_PMSTAT_WFI_MAX                (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_PMSTAT_RESERVED_MASK          (0xFFFFFFFEU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_PMSTAT_RESERVED_SHIFT         (0x00000001U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE0_PMSTAT_RESERVED_MAX           (0x7FFFFFFFU)

/* CLSTR16_CORE1_CFG */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_CFG_RESERVED_MASK             (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_CFG_RESERVED_SHIFT            (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_CFG_RESERVED_MAX              (0xFFFFFFFFU)

/* CLSTR16_CORE1_BOOTVECT_LO */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_BOOTVECT_LO_RESERVED_MASK     (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_BOOTVECT_LO_RESERVED_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_BOOTVECT_LO_RESERVED_MAX      (0xFFFFFFFFU)

/* CLSTR16_CORE1_BOOTVECT_HI */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_BOOTVECT_HI_RESERVED_MASK     (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_BOOTVECT_HI_RESERVED_SHIFT    (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_BOOTVECT_HI_RESERVED_MAX      (0xFFFFFFFFU)

/* CLSTR16_CORE1_PMCTRL */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_PMCTRL_RESERVED_MASK          (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_PMCTRL_RESERVED_SHIFT         (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_PMCTRL_RESERVED_MAX           (0xFFFFFFFFU)

/* CLSTR16_CORE1_PMSTAT */

#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_PMSTAT_RESERVED_MASK          (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_PMSTAT_RESERVED_SHIFT         (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG0_CLSTR16_CORE1_PMSTAT_RESERVED_MAX           (0xFFFFFFFFU)

/* GIC_CONFIG */

#define CSL_MAIN_SEC_MMR_CFG0_GIC_CONFIG_A53SS0_CORE0_ACTIVE_MASK         (0x00000100U)
#define CSL_MAIN_SEC_MMR_CFG0_GIC_CONFIG_A53SS0_CORE0_ACTIVE_SHIFT        (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG0_GIC_CONFIG_A53SS0_CORE0_ACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_SEC_MMR_CFG0_GIC_CONFIG_A53SS0_CORE1_ACTIVE_MASK         (0x00000200U)
#define CSL_MAIN_SEC_MMR_CFG0_GIC_CONFIG_A53SS0_CORE1_ACTIVE_SHIFT        (0x00000009U)
#define CSL_MAIN_SEC_MMR_CFG0_GIC_CONFIG_A53SS0_CORE1_ACTIVE_MAX          (0x00000001U)

/**************************************************************************
* Hardware Region  : MMRs in region 2
**************************************************************************/


/**************************************************************************
* Register Overlay Structure
**************************************************************************/

typedef struct {
    volatile uint32_t CLSTR0_CORE0_DBG_CFG;
    volatile uint8_t  Resv_64[60];
    volatile uint32_t CLSTR0_CORE1_DBG_CFG;
    volatile uint8_t  Resv_4096[4028];
    volatile uint32_t CLSTR1_CORE0_DBG_CFG;
    volatile uint8_t  Resv_4160[60];
    volatile uint32_t CLSTR1_CORE1_DBG_CFG;
    volatile uint8_t  Resv_36864[32700];
    volatile uint32_t CLSTR9_CORE0_DBG_CFG;
    volatile uint8_t  Resv_36928[60];
    volatile uint32_t CLSTR9_CORE1_DBG_CFG;
    volatile uint8_t  Resv_65536[28604];
    volatile uint32_t CLSTR16_CORE0_DBG_CFG;
    volatile uint8_t  Resv_65600[60];
    volatile uint32_t CLSTR16_CORE1_DBG_CFG;
} CSL_main_sec_mmr_cfg2Regs;


/**************************************************************************
* Register Macros
**************************************************************************/

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE0_DBG_CFG                        (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE1_DBG_CFG                        (0x00000040U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE0_DBG_CFG                        (0x00001000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE1_DBG_CFG                        (0x00001040U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG                        (0x00009000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG                        (0x00009040U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR16_CORE0_DBG_CFG                       (0x00010000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR16_CORE1_DBG_CFG                       (0x00010040U)

/**************************************************************************
* Field Definition Macros
**************************************************************************/


/* CLSTR0_CORE0_DBG_CFG */

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE0_DBG_CFG_NIDEN_MASK             (0x00000F00U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE0_DBG_CFG_NIDEN_SHIFT            (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE0_DBG_CFG_NIDEN_MAX              (0x0000000FU)

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE0_DBG_CFG_DBGEN_MASK             (0x0000F000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE0_DBG_CFG_DBGEN_SHIFT            (0x0000000CU)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE0_DBG_CFG_DBGEN_MAX              (0x0000000FU)

/* CLSTR0_CORE1_DBG_CFG */

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE1_DBG_CFG_NIDEN_MASK             (0x00000F00U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE1_DBG_CFG_NIDEN_SHIFT            (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE1_DBG_CFG_NIDEN_MAX              (0x0000000FU)

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE1_DBG_CFG_DBGEN_MASK             (0x0000F000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE1_DBG_CFG_DBGEN_SHIFT            (0x0000000CU)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR0_CORE1_DBG_CFG_DBGEN_MAX              (0x0000000FU)

/* CLSTR1_CORE0_DBG_CFG */

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE0_DBG_CFG_NIDEN_MASK             (0x00000F00U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE0_DBG_CFG_NIDEN_SHIFT            (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE0_DBG_CFG_NIDEN_MAX              (0x0000000FU)

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE0_DBG_CFG_DBGEN_MASK             (0x0000F000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE0_DBG_CFG_DBGEN_SHIFT            (0x0000000CU)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE0_DBG_CFG_DBGEN_MAX              (0x0000000FU)

/* CLSTR1_CORE1_DBG_CFG */

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE1_DBG_CFG_NIDEN_MASK             (0x00000F00U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE1_DBG_CFG_NIDEN_SHIFT            (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE1_DBG_CFG_NIDEN_MAX              (0x0000000FU)

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE1_DBG_CFG_DBGEN_MASK             (0x0000F000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE1_DBG_CFG_DBGEN_SHIFT            (0x0000000CU)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR1_CORE1_DBG_CFG_DBGEN_MAX              (0x0000000FU)

/* CLSTR9_CORE0_DBG_CFG */

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_DBGEN_MASK             (0x0000000FU)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_DBGEN_SHIFT            (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_DBGEN_MAX              (0x0000000FU)

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_NIDEN_MASK             (0x000000F0U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_NIDEN_SHIFT            (0x00000004U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_NIDEN_MAX              (0x0000000FU)

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_SPIDEN_MASK            (0x00000F00U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_SPIDEN_SHIFT           (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_SPIDEN_MAX             (0x0000000FU)

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_SPNIDEN_MASK           (0x0000F000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_SPNIDEN_SHIFT          (0x0000000CU)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE0_DBG_CFG_SPNIDEN_MAX            (0x0000000FU)

/* CLSTR9_CORE1_DBG_CFG */

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_DBGEN_MASK             (0x0000000FU)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_DBGEN_SHIFT            (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_DBGEN_MAX              (0x0000000FU)

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_NIDEN_MASK             (0x000000F0U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_NIDEN_SHIFT            (0x00000004U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_NIDEN_MAX              (0x0000000FU)

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_SPIDEN_MASK            (0x00000F00U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_SPIDEN_SHIFT           (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_SPIDEN_MAX             (0x0000000FU)

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_SPNIDEN_MASK           (0x0000F000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_SPNIDEN_SHIFT          (0x0000000CU)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR9_CORE1_DBG_CFG_SPNIDEN_MAX            (0x0000000FU)

/* CLSTR16_CORE0_DBG_CFG */

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR16_CORE0_DBG_CFG_NIDEN_MASK            (0x00000F00U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR16_CORE0_DBG_CFG_NIDEN_SHIFT           (0x00000008U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR16_CORE0_DBG_CFG_NIDEN_MAX             (0x0000000FU)

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR16_CORE0_DBG_CFG_DBGEN_MASK            (0x0000F000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR16_CORE0_DBG_CFG_DBGEN_SHIFT           (0x0000000CU)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR16_CORE0_DBG_CFG_DBGEN_MAX             (0x0000000FU)

/* CLSTR16_CORE1_DBG_CFG */

#define CSL_MAIN_SEC_MMR_CFG2_CLSTR16_CORE1_DBG_CFG_RESERVED_MASK         (0xFFFFFFFFU)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR16_CORE1_DBG_CFG_RESERVED_SHIFT        (0x00000000U)
#define CSL_MAIN_SEC_MMR_CFG2_CLSTR16_CORE1_DBG_CFG_RESERVED_MAX          (0xFFFFFFFFU)

#ifdef __cplusplus
}
#endif
#endif
