/********************************************************************
 * Copyright (C) 2022 Texas Instruments Incorporated.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *  Name        : cslr_main_padcfg_ctrl_mmr.h
*/
#ifndef CSLR_MAIN_PADCFG_CTRL_MMR_H_
#define CSLR_MAIN_PADCFG_CTRL_MMR_H_

#ifdef __cplusplus
extern "C"
{
#endif
#include <drivers/hw_include/cslr.h>
#include <stdint.h>

/**************************************************************************
* Module Base Offset Values
**************************************************************************/

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_REGS_BASE                         (0x00000000U)


/**************************************************************************
* Hardware Region  : MMRs in region 0
**************************************************************************/


/**************************************************************************
* Register Overlay Structure
**************************************************************************/

typedef struct {
    volatile uint32_t PID;                       /* PID register */
    volatile uint32_t MMR_CFG0;
    volatile uint32_t MMR_CFG1;
    volatile uint8_t  Resv_4104[4092];
    volatile uint32_t LOCK0_KICK0;               /*  - KICK0 component */
    volatile uint32_t LOCK0_KICK1;               /*  - KICK1 component */
    volatile uint32_t INTR_RAW_STATUS;           /* Interrupt Raw Status/Set Register */
    volatile uint32_t INTR_ENABLED_STATUS_CLEAR;   /* Interrupt Enabled Status/Clear register */
    volatile uint32_t INTR_ENABLE;               /* Interrupt Enable register */
    volatile uint32_t INTR_ENABLE_CLEAR;         /* Interrupt Enable Clear register */
    volatile uint32_t EOI;                       /* EOI register */
    volatile uint32_t FAULT_ADDRESS;             /* Fault Address register */
    volatile uint32_t FAULT_TYPE_STATUS;         /* Fault Type Status register */
    volatile uint32_t FAULT_ATTR_STATUS;         /* Fault Attribute Status register */
    volatile uint32_t FAULT_CLEAR;               /* Fault Clear register */
    volatile uint8_t  Resv_4352[204];
    volatile uint32_t CLAIMREG_P0_R0_READONLY;   /* Claim bits for Partition 0 */
    volatile uint8_t  Resv_8192[3836];
    volatile uint32_t PID_PROXY;                 /* PID register */
    volatile uint32_t MMR_CFG0_PROXY;
    volatile uint32_t MMR_CFG1_PROXY;
    volatile uint8_t  Resv_12296[4092];
    volatile uint32_t LOCK0_KICK0_PROXY;         /*  - KICK0 component */
    volatile uint32_t LOCK0_KICK1_PROXY;         /*  - KICK1 component */
    volatile uint32_t INTR_RAW_STATUS_PROXY;     /* Interrupt Raw Status/Set Register */
    volatile uint32_t INTR_ENABLED_STATUS_CLEAR_PROXY;   /* Interrupt Enabled Status/Clear register */
    volatile uint32_t INTR_ENABLE_PROXY;         /* Interrupt Enable register */
    volatile uint32_t INTR_ENABLE_CLEAR_PROXY;   /* Interrupt Enable Clear register */
    volatile uint32_t EOI_PROXY;                 /* EOI register */
    volatile uint32_t FAULT_ADDRESS_PROXY;       /* Fault Address register */
    volatile uint32_t FAULT_TYPE_STATUS_PROXY;   /* Fault Type Status register */
    volatile uint32_t FAULT_ATTR_STATUS_PROXY;   /* Fault Attribute Status register */
    volatile uint32_t FAULT_CLEAR_PROXY;         /* Fault Clear register */
    volatile uint8_t  Resv_12544[204];
    volatile uint32_t CLAIMREG_P0_R0;            /* Claim bits for Partition 0 */
    volatile uint8_t  Resv_16384[3836];
    volatile uint32_t PADCONFIG0;
    volatile uint32_t PADCONFIG1;
    volatile uint32_t PADCONFIG2;
    volatile uint32_t PADCONFIG3;
    volatile uint32_t PADCONFIG4;
    volatile uint32_t PADCONFIG5;
    volatile uint32_t PADCONFIG6;
    volatile uint32_t PADCONFIG7;
    volatile uint32_t PADCONFIG8;
    volatile uint32_t PADCONFIG9;
    volatile uint32_t PADCONFIG10;
    volatile uint32_t PADCONFIG11;
    volatile uint32_t PADCONFIG12;
    volatile uint32_t PADCONFIG13;
    volatile uint32_t PADCONFIG14;
    volatile uint32_t PADCONFIG15;
    volatile uint32_t PADCONFIG16;
    volatile uint32_t PADCONFIG17;
    volatile uint32_t PADCONFIG18;
    volatile uint32_t PADCONFIG19;
    volatile uint32_t PADCONFIG20;
    volatile uint32_t PADCONFIG21;
    volatile uint32_t PADCONFIG22;
    volatile uint32_t PADCONFIG23;
    volatile uint32_t PADCONFIG24;
    volatile uint32_t PADCONFIG25;
    volatile uint32_t PADCONFIG26;
    volatile uint32_t PADCONFIG27;
    volatile uint32_t PADCONFIG28;
    volatile uint32_t PADCONFIG29;
    volatile uint32_t PADCONFIG30;
    volatile uint32_t PADCONFIG31;
    volatile uint32_t PADCONFIG32;
    volatile uint32_t PADCONFIG33;
    volatile uint32_t PADCONFIG34;
    volatile uint32_t PADCONFIG35;
    volatile uint32_t PADCONFIG36;
    volatile uint32_t PADCONFIG37;
    volatile uint32_t PADCONFIG38;
    volatile uint32_t PADCONFIG39;
    volatile uint32_t PADCONFIG40;
    volatile uint32_t PADCONFIG41;
    volatile uint32_t PADCONFIG42;
    volatile uint32_t PADCONFIG43;
    volatile uint32_t PADCONFIG44;
    volatile uint32_t PADCONFIG45;
    volatile uint32_t PADCONFIG46;
    volatile uint32_t PADCONFIG47;
    volatile uint32_t PADCONFIG48;
    volatile uint32_t PADCONFIG49;
    volatile uint32_t PADCONFIG50;
    volatile uint32_t PADCONFIG51;
    volatile uint32_t PADCONFIG52;
    volatile uint32_t PADCONFIG53;
    volatile uint32_t PADCONFIG54;
    volatile uint32_t PADCONFIG55;
    volatile uint32_t PADCONFIG56;
    volatile uint32_t PADCONFIG57;
    volatile uint32_t PADCONFIG58;
    volatile uint32_t PADCONFIG59;
    volatile uint32_t PADCONFIG60;
    volatile uint32_t PADCONFIG61;
    volatile uint32_t PADCONFIG62;
    volatile uint32_t PADCONFIG63;
    volatile uint32_t PADCONFIG64;
    volatile uint32_t PADCONFIG65;
    volatile uint32_t PADCONFIG66;
    volatile uint32_t PADCONFIG67;
    volatile uint32_t PADCONFIG68;
    volatile uint32_t PADCONFIG69;
    volatile uint32_t PADCONFIG70;
    volatile uint32_t PADCONFIG71;
    volatile uint32_t PADCONFIG72;
    volatile uint32_t PADCONFIG73;
    volatile uint32_t PADCONFIG74;
    volatile uint32_t PADCONFIG75;
    volatile uint32_t PADCONFIG76;
    volatile uint32_t PADCONFIG77;
    volatile uint32_t PADCONFIG78;
    volatile uint32_t PADCONFIG79;
    volatile uint32_t PADCONFIG80;
    volatile uint32_t PADCONFIG81;
    volatile uint32_t PADCONFIG82;
    volatile uint32_t PADCONFIG83;
    volatile uint32_t PADCONFIG84;
    volatile uint32_t PADCONFIG85;
    volatile uint32_t PADCONFIG86;
    volatile uint32_t PADCONFIG87;
    volatile uint32_t PADCONFIG88;
    volatile uint32_t PADCONFIG89;
    volatile uint32_t PADCONFIG90;
    volatile uint32_t PADCONFIG91;
    volatile uint32_t PADCONFIG92;
    volatile uint32_t PADCONFIG93;
    volatile uint32_t PADCONFIG94;
    volatile uint32_t PADCONFIG95;
    volatile uint32_t PADCONFIG96;
    volatile uint32_t PADCONFIG97;
    volatile uint32_t PADCONFIG98;
    volatile uint32_t PADCONFIG99;
    volatile uint32_t PADCONFIG100;
    volatile uint32_t PADCONFIG101;
    volatile uint32_t PADCONFIG102;
    volatile uint32_t PADCONFIG103;
    volatile uint32_t PADCONFIG104;
    volatile uint32_t PADCONFIG105;
    volatile uint32_t PADCONFIG106;
    volatile uint32_t PADCONFIG107;
    volatile uint32_t PADCONFIG108;
    volatile uint32_t PADCONFIG109;
    volatile uint32_t PADCONFIG110;
    volatile uint32_t PADCONFIG111;
    volatile uint32_t PADCONFIG112;
    volatile uint32_t PADCONFIG113;
    volatile uint32_t PADCONFIG114;
    volatile uint32_t PADCONFIG115;
    volatile uint32_t PADCONFIG116;
    volatile uint32_t PADCONFIG117;
    volatile uint32_t PADCONFIG118;
    volatile uint32_t PADCONFIG119;
    volatile uint32_t PADCONFIG120;
    volatile uint32_t PADCONFIG121;
    volatile uint32_t PADCONFIG122;
    volatile uint32_t PADCONFIG123;
    volatile uint32_t PADCONFIG124;
    volatile uint32_t PADCONFIG125;
    volatile uint32_t PADCONFIG126;
    volatile uint32_t PADCONFIG127;
    volatile uint32_t PADCONFIG128;
    volatile uint32_t PADCONFIG129;
    volatile uint32_t PADCONFIG130;
    volatile uint32_t PADCONFIG131;
    volatile uint32_t PADCONFIG132;
    volatile uint32_t PADCONFIG133;
    volatile uint32_t PADCONFIG134;
    volatile uint32_t PADCONFIG135;
    volatile uint32_t PADCONFIG136;
    volatile uint32_t PADCONFIG137;
    volatile uint32_t PADCONFIG138;
    volatile uint32_t PADCONFIG139;
    volatile uint32_t PADCONFIG140;
    volatile uint32_t PADCONFIG141;
    volatile uint32_t PADCONFIG142;
    volatile uint32_t PADCONFIG143;
    volatile uint32_t PADCONFIG144;
    volatile uint32_t PADCONFIG145;
    volatile uint32_t PADCONFIG146;
    volatile uint32_t PADCONFIG147;
    volatile uint32_t PADCONFIG148;
    volatile uint32_t PADCONFIG149;
    volatile uint32_t PADCONFIG150;
    volatile uint32_t PADCONFIG151;
    volatile uint32_t PADCONFIG152;
    volatile uint32_t PADCONFIG153;
    volatile uint32_t PADCONFIG154;
    volatile uint32_t PADCONFIG155;
    volatile uint32_t PADCONFIG156;
    volatile uint32_t PADCONFIG157;
    volatile uint32_t PADCONFIG158;
    volatile uint32_t PADCONFIG159;
    volatile uint32_t PADCONFIG160;
    volatile uint32_t PADCONFIG161;
    volatile uint32_t PADCONFIG162;
    volatile uint32_t PADCONFIG163;
    volatile uint32_t PADCONFIG164;
    volatile uint32_t PADCONFIG165;
    volatile uint32_t PADCONFIG166;
    volatile uint32_t PADCONFIG167;
    volatile uint32_t PADCONFIG168;
    volatile uint32_t PADCONFIG169;
    volatile uint32_t PADCONFIG170;
    volatile uint32_t PADCONFIG171;
    volatile uint32_t PADCONFIG172;
    volatile uint32_t PADCONFIG173;
    volatile uint32_t PADCONFIG174;
    volatile uint32_t PADCONFIG175;
    volatile uint32_t PADCONFIG176;
    volatile uint32_t PADCONFIG177;
    volatile uint32_t PADCONFIG178;
    volatile uint32_t PADCONFIG179;
    volatile uint32_t PADCONFIG180;
    volatile uint32_t PADCONFIG181;
    volatile uint8_t  Resv_20488[3376];
    volatile uint32_t LOCK1_KICK0;               /*  - KICK0 component */
    volatile uint32_t LOCK1_KICK1;               /*  - KICK1 component */
    volatile uint8_t  Resv_20736[240];
    volatile uint32_t CLAIMREG_P1_R0_READONLY;   /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R1_READONLY;   /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R2_READONLY;   /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R3_READONLY;   /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R4_READONLY;   /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R5_READONLY;   /* Claim bits for Partition 1 */
    volatile uint8_t  Resv_24576[3816];
    volatile uint32_t PADCONFIG0_PROXY;
    volatile uint32_t PADCONFIG1_PROXY;
    volatile uint32_t PADCONFIG2_PROXY;
    volatile uint32_t PADCONFIG3_PROXY;
    volatile uint32_t PADCONFIG4_PROXY;
    volatile uint32_t PADCONFIG5_PROXY;
    volatile uint32_t PADCONFIG6_PROXY;
    volatile uint32_t PADCONFIG7_PROXY;
    volatile uint32_t PADCONFIG8_PROXY;
    volatile uint32_t PADCONFIG9_PROXY;
    volatile uint32_t PADCONFIG10_PROXY;
    volatile uint32_t PADCONFIG11_PROXY;
    volatile uint32_t PADCONFIG12_PROXY;
    volatile uint32_t PADCONFIG13_PROXY;
    volatile uint32_t PADCONFIG14_PROXY;
    volatile uint32_t PADCONFIG15_PROXY;
    volatile uint32_t PADCONFIG16_PROXY;
    volatile uint32_t PADCONFIG17_PROXY;
    volatile uint32_t PADCONFIG18_PROXY;
    volatile uint32_t PADCONFIG19_PROXY;
    volatile uint32_t PADCONFIG20_PROXY;
    volatile uint32_t PADCONFIG21_PROXY;
    volatile uint32_t PADCONFIG22_PROXY;
    volatile uint32_t PADCONFIG23_PROXY;
    volatile uint32_t PADCONFIG24_PROXY;
    volatile uint32_t PADCONFIG25_PROXY;
    volatile uint32_t PADCONFIG26_PROXY;
    volatile uint32_t PADCONFIG27_PROXY;
    volatile uint32_t PADCONFIG28_PROXY;
    volatile uint32_t PADCONFIG29_PROXY;
    volatile uint32_t PADCONFIG30_PROXY;
    volatile uint32_t PADCONFIG31_PROXY;
    volatile uint32_t PADCONFIG32_PROXY;
    volatile uint32_t PADCONFIG33_PROXY;
    volatile uint32_t PADCONFIG34_PROXY;
    volatile uint32_t PADCONFIG35_PROXY;
    volatile uint32_t PADCONFIG36_PROXY;
    volatile uint32_t PADCONFIG37_PROXY;
    volatile uint32_t PADCONFIG38_PROXY;
    volatile uint32_t PADCONFIG39_PROXY;
    volatile uint32_t PADCONFIG40_PROXY;
    volatile uint32_t PADCONFIG41_PROXY;
    volatile uint32_t PADCONFIG42_PROXY;
    volatile uint32_t PADCONFIG43_PROXY;
    volatile uint32_t PADCONFIG44_PROXY;
    volatile uint32_t PADCONFIG45_PROXY;
    volatile uint32_t PADCONFIG46_PROXY;
    volatile uint32_t PADCONFIG47_PROXY;
    volatile uint32_t PADCONFIG48_PROXY;
    volatile uint32_t PADCONFIG49_PROXY;
    volatile uint32_t PADCONFIG50_PROXY;
    volatile uint32_t PADCONFIG51_PROXY;
    volatile uint32_t PADCONFIG52_PROXY;
    volatile uint32_t PADCONFIG53_PROXY;
    volatile uint32_t PADCONFIG54_PROXY;
    volatile uint32_t PADCONFIG55_PROXY;
    volatile uint32_t PADCONFIG56_PROXY;
    volatile uint32_t PADCONFIG57_PROXY;
    volatile uint32_t PADCONFIG58_PROXY;
    volatile uint32_t PADCONFIG59_PROXY;
    volatile uint32_t PADCONFIG60_PROXY;
    volatile uint32_t PADCONFIG61_PROXY;
    volatile uint32_t PADCONFIG62_PROXY;
    volatile uint32_t PADCONFIG63_PROXY;
    volatile uint32_t PADCONFIG64_PROXY;
    volatile uint32_t PADCONFIG65_PROXY;
    volatile uint32_t PADCONFIG66_PROXY;
    volatile uint32_t PADCONFIG67_PROXY;
    volatile uint32_t PADCONFIG68_PROXY;
    volatile uint32_t PADCONFIG69_PROXY;
    volatile uint32_t PADCONFIG70_PROXY;
    volatile uint32_t PADCONFIG71_PROXY;
    volatile uint32_t PADCONFIG72_PROXY;
    volatile uint32_t PADCONFIG73_PROXY;
    volatile uint32_t PADCONFIG74_PROXY;
    volatile uint32_t PADCONFIG75_PROXY;
    volatile uint32_t PADCONFIG76_PROXY;
    volatile uint32_t PADCONFIG77_PROXY;
    volatile uint32_t PADCONFIG78_PROXY;
    volatile uint32_t PADCONFIG79_PROXY;
    volatile uint32_t PADCONFIG80_PROXY;
    volatile uint32_t PADCONFIG81_PROXY;
    volatile uint32_t PADCONFIG82_PROXY;
    volatile uint32_t PADCONFIG83_PROXY;
    volatile uint32_t PADCONFIG84_PROXY;
    volatile uint32_t PADCONFIG85_PROXY;
    volatile uint32_t PADCONFIG86_PROXY;
    volatile uint32_t PADCONFIG87_PROXY;
    volatile uint32_t PADCONFIG88_PROXY;
    volatile uint32_t PADCONFIG89_PROXY;
    volatile uint32_t PADCONFIG90_PROXY;
    volatile uint32_t PADCONFIG91_PROXY;
    volatile uint32_t PADCONFIG92_PROXY;
    volatile uint32_t PADCONFIG93_PROXY;
    volatile uint32_t PADCONFIG94_PROXY;
    volatile uint32_t PADCONFIG95_PROXY;
    volatile uint32_t PADCONFIG96_PROXY;
    volatile uint32_t PADCONFIG97_PROXY;
    volatile uint32_t PADCONFIG98_PROXY;
    volatile uint32_t PADCONFIG99_PROXY;
    volatile uint32_t PADCONFIG100_PROXY;
    volatile uint32_t PADCONFIG101_PROXY;
    volatile uint32_t PADCONFIG102_PROXY;
    volatile uint32_t PADCONFIG103_PROXY;
    volatile uint32_t PADCONFIG104_PROXY;
    volatile uint32_t PADCONFIG105_PROXY;
    volatile uint32_t PADCONFIG106_PROXY;
    volatile uint32_t PADCONFIG107_PROXY;
    volatile uint32_t PADCONFIG108_PROXY;
    volatile uint32_t PADCONFIG109_PROXY;
    volatile uint32_t PADCONFIG110_PROXY;
    volatile uint32_t PADCONFIG111_PROXY;
    volatile uint32_t PADCONFIG112_PROXY;
    volatile uint32_t PADCONFIG113_PROXY;
    volatile uint32_t PADCONFIG114_PROXY;
    volatile uint32_t PADCONFIG115_PROXY;
    volatile uint32_t PADCONFIG116_PROXY;
    volatile uint32_t PADCONFIG117_PROXY;
    volatile uint32_t PADCONFIG118_PROXY;
    volatile uint32_t PADCONFIG119_PROXY;
    volatile uint32_t PADCONFIG120_PROXY;
    volatile uint32_t PADCONFIG121_PROXY;
    volatile uint32_t PADCONFIG122_PROXY;
    volatile uint32_t PADCONFIG123_PROXY;
    volatile uint32_t PADCONFIG124_PROXY;
    volatile uint32_t PADCONFIG125_PROXY;
    volatile uint32_t PADCONFIG126_PROXY;
    volatile uint32_t PADCONFIG127_PROXY;
    volatile uint32_t PADCONFIG128_PROXY;
    volatile uint32_t PADCONFIG129_PROXY;
    volatile uint32_t PADCONFIG130_PROXY;
    volatile uint32_t PADCONFIG131_PROXY;
    volatile uint32_t PADCONFIG132_PROXY;
    volatile uint32_t PADCONFIG133_PROXY;
    volatile uint32_t PADCONFIG134_PROXY;
    volatile uint32_t PADCONFIG135_PROXY;
    volatile uint32_t PADCONFIG136_PROXY;
    volatile uint32_t PADCONFIG137_PROXY;
    volatile uint32_t PADCONFIG138_PROXY;
    volatile uint32_t PADCONFIG139_PROXY;
    volatile uint32_t PADCONFIG140_PROXY;
    volatile uint32_t PADCONFIG141_PROXY;
    volatile uint32_t PADCONFIG142_PROXY;
    volatile uint32_t PADCONFIG143_PROXY;
    volatile uint32_t PADCONFIG144_PROXY;
    volatile uint32_t PADCONFIG145_PROXY;
    volatile uint32_t PADCONFIG146_PROXY;
    volatile uint32_t PADCONFIG147_PROXY;
    volatile uint32_t PADCONFIG148_PROXY;
    volatile uint32_t PADCONFIG149_PROXY;
    volatile uint32_t PADCONFIG150_PROXY;
    volatile uint32_t PADCONFIG151_PROXY;
    volatile uint32_t PADCONFIG152_PROXY;
    volatile uint32_t PADCONFIG153_PROXY;
    volatile uint32_t PADCONFIG154_PROXY;
    volatile uint32_t PADCONFIG155_PROXY;
    volatile uint32_t PADCONFIG156_PROXY;
    volatile uint32_t PADCONFIG157_PROXY;
    volatile uint32_t PADCONFIG158_PROXY;
    volatile uint32_t PADCONFIG159_PROXY;
    volatile uint32_t PADCONFIG160_PROXY;
    volatile uint32_t PADCONFIG161_PROXY;
    volatile uint32_t PADCONFIG162_PROXY;
    volatile uint32_t PADCONFIG163_PROXY;
    volatile uint32_t PADCONFIG164_PROXY;
    volatile uint32_t PADCONFIG165_PROXY;
    volatile uint32_t PADCONFIG166_PROXY;
    volatile uint32_t PADCONFIG167_PROXY;
    volatile uint32_t PADCONFIG168_PROXY;
    volatile uint32_t PADCONFIG169_PROXY;
    volatile uint32_t PADCONFIG170_PROXY;
    volatile uint32_t PADCONFIG171_PROXY;
    volatile uint32_t PADCONFIG172_PROXY;
    volatile uint32_t PADCONFIG173_PROXY;
    volatile uint32_t PADCONFIG174_PROXY;
    volatile uint32_t PADCONFIG175_PROXY;
    volatile uint32_t PADCONFIG176_PROXY;
    volatile uint32_t PADCONFIG177_PROXY;
    volatile uint32_t PADCONFIG178_PROXY;
    volatile uint32_t PADCONFIG179_PROXY;
    volatile uint32_t PADCONFIG180_PROXY;
    volatile uint32_t PADCONFIG181_PROXY;
    volatile uint8_t  Resv_28680[3376];
    volatile uint32_t LOCK1_KICK0_PROXY;         /*  - KICK0 component */
    volatile uint32_t LOCK1_KICK1_PROXY;         /*  - KICK1 component */
    volatile uint8_t  Resv_28928[240];
    volatile uint32_t CLAIMREG_P1_R0;            /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R1;            /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R2;            /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R3;            /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R4;            /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R5;            /* Claim bits for Partition 1 */
} CSL_main_padcfg_ctrl_mmr_cfg0Regs;


/**************************************************************************
* Register Macros
**************************************************************************/

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID                               (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0                          (0x00000004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1                          (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0                       (0x00001008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1                       (0x0000100CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS                   (0x00001010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR         (0x00001014U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE                       (0x00001018U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR                 (0x0000101CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_EOI                               (0x00001020U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS                     (0x00001024U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS                 (0x00001028U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS                 (0x0000102CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR                       (0x00001030U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_READONLY           (0x00001100U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY                         (0x00002000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY                    (0x00002004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY                    (0x00002008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_PROXY                 (0x00003008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_PROXY                 (0x0000300CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY             (0x00003010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY   (0x00003014U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY                 (0x00003018U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY           (0x0000301CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_EOI_PROXY                         (0x00003020U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_PROXY               (0x00003024U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY           (0x00003028U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY           (0x0000302CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_PROXY                 (0x00003030U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0                    (0x00003100U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0                        (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1                        (0x00004004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2                        (0x00004008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3                        (0x0000400CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4                        (0x00004010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5                        (0x00004014U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6                        (0x00004018U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7                        (0x0000401CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8                        (0x00004020U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9                        (0x00004024U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10                       (0x00004028U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11                       (0x0000402CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12                       (0x00004030U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13                       (0x00004034U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14                       (0x00004038U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15                       (0x0000403CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16                       (0x00004040U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17                       (0x00004044U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18                       (0x00004048U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19                       (0x0000404CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20                       (0x00004050U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21                       (0x00004054U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22                       (0x00004058U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23                       (0x0000405CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24                       (0x00004060U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25                       (0x00004064U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26                       (0x00004068U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27                       (0x0000406CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28                       (0x00004070U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29                       (0x00004074U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30                       (0x00004078U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31                       (0x0000407CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32                       (0x00004080U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33                       (0x00004084U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34                       (0x00004088U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35                       (0x0000408CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36                       (0x00004090U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37                       (0x00004094U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38                       (0x00004098U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39                       (0x0000409CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40                       (0x000040A0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41                       (0x000040A4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42                       (0x000040A8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43                       (0x000040ACU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44                       (0x000040B0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45                       (0x000040B4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46                       (0x000040B8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47                       (0x000040BCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48                       (0x000040C0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49                       (0x000040C4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50                       (0x000040C8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51                       (0x000040CCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52                       (0x000040D0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53                       (0x000040D4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54                       (0x000040D8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55                       (0x000040DCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56                       (0x000040E0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57                       (0x000040E4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58                       (0x000040E8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59                       (0x000040ECU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60                       (0x000040F0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61                       (0x000040F4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62                       (0x000040F8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63                       (0x000040FCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64                       (0x00004100U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65                       (0x00004104U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66                       (0x00004108U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67                       (0x0000410CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68                       (0x00004110U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69                       (0x00004114U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70                       (0x00004118U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71                       (0x0000411CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72                       (0x00004120U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73                       (0x00004124U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74                       (0x00004128U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75                       (0x0000412CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76                       (0x00004130U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77                       (0x00004134U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78                       (0x00004138U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79                       (0x0000413CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80                       (0x00004140U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81                       (0x00004144U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82                       (0x00004148U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83                       (0x0000414CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84                       (0x00004150U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85                       (0x00004154U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86                       (0x00004158U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87                       (0x0000415CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88                       (0x00004160U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89                       (0x00004164U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90                       (0x00004168U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91                       (0x0000416CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92                       (0x00004170U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93                       (0x00004174U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94                       (0x00004178U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95                       (0x0000417CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96                       (0x00004180U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97                       (0x00004184U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98                       (0x00004188U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99                       (0x0000418CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100                      (0x00004190U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101                      (0x00004194U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102                      (0x00004198U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103                      (0x0000419CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104                      (0x000041A0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105                      (0x000041A4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106                      (0x000041A8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107                      (0x000041ACU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108                      (0x000041B0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109                      (0x000041B4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110                      (0x000041B8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111                      (0x000041BCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112                      (0x000041C0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113                      (0x000041C4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114                      (0x000041C8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115                      (0x000041CCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116                      (0x000041D0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117                      (0x000041D4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118                      (0x000041D8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119                      (0x000041DCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120                      (0x000041E0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121                      (0x000041E4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122                      (0x000041E8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123                      (0x000041ECU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124                      (0x000041F0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125                      (0x000041F4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126                      (0x000041F8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127                      (0x000041FCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128                      (0x00004200U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129                      (0x00004204U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130                      (0x00004208U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131                      (0x0000420CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132                      (0x00004210U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133                      (0x00004214U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134                      (0x00004218U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135                      (0x0000421CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136                      (0x00004220U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137                      (0x00004224U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138                      (0x00004228U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139                      (0x0000422CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140                      (0x00004230U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141                      (0x00004234U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142                      (0x00004238U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143                      (0x0000423CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144                      (0x00004240U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145                      (0x00004244U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146                      (0x00004248U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147                      (0x0000424CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148                      (0x00004250U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149                      (0x00004254U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150                      (0x00004258U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151                      (0x0000425CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152                      (0x00004260U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153                      (0x00004264U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154                      (0x00004268U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155                      (0x0000426CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156                      (0x00004270U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157                      (0x00004274U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158                      (0x00004278U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159                      (0x0000427CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160                      (0x00004280U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161                      (0x00004284U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162                      (0x00004288U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163                      (0x0000428CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164                      (0x00004290U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165                      (0x00004294U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166                      (0x00004298U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167                      (0x0000429CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168                      (0x000042A0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169                      (0x000042A4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170                      (0x000042A8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171                      (0x000042ACU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172                      (0x000042B0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173                      (0x000042B4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174                      (0x000042B8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175                      (0x000042BCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176                      (0x000042C0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177                      (0x000042C4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178                      (0x000042C8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179                      (0x000042CCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180                      (0x000042D0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181                      (0x000042D4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0                       (0x00005008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1                       (0x0000500CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_READONLY           (0x00005100U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_READONLY           (0x00005104U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R2_READONLY           (0x00005108U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R3_READONLY           (0x0000510CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R4_READONLY           (0x00005110U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R5_READONLY           (0x00005114U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY                  (0x00006000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY                  (0x00006004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY                  (0x00006008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY                  (0x0000600CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY                  (0x00006010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY                  (0x00006014U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY                  (0x00006018U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY                  (0x0000601CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY                  (0x00006020U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY                  (0x00006024U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY                 (0x00006028U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY                 (0x0000602CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY                 (0x00006030U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY                 (0x00006034U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY                 (0x00006038U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY                 (0x0000603CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY                 (0x00006040U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY                 (0x00006044U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY                 (0x00006048U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY                 (0x0000604CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY                 (0x00006050U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY                 (0x00006054U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY                 (0x00006058U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY                 (0x0000605CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY                 (0x00006060U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY                 (0x00006064U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY                 (0x00006068U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY                 (0x0000606CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY                 (0x00006070U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY                 (0x00006074U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY                 (0x00006078U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY                 (0x0000607CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY                 (0x00006080U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY                 (0x00006084U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY                 (0x00006088U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY                 (0x0000608CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY                 (0x00006090U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY                 (0x00006094U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY                 (0x00006098U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY                 (0x0000609CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY                 (0x000060A0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY                 (0x000060A4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY                 (0x000060A8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY                 (0x000060ACU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY                 (0x000060B0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY                 (0x000060B4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY                 (0x000060B8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY                 (0x000060BCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY                 (0x000060C0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY                 (0x000060C4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY                 (0x000060C8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY                 (0x000060CCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY                 (0x000060D0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY                 (0x000060D4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY                 (0x000060D8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY                 (0x000060DCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY                 (0x000060E0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY                 (0x000060E4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY                 (0x000060E8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY                 (0x000060ECU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY                 (0x000060F0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY                 (0x000060F4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY                 (0x000060F8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY                 (0x000060FCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY                 (0x00006100U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY                 (0x00006104U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY                 (0x00006108U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY                 (0x0000610CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY                 (0x00006110U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY                 (0x00006114U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY                 (0x00006118U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY                 (0x0000611CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY                 (0x00006120U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY                 (0x00006124U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY                 (0x00006128U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY                 (0x0000612CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY                 (0x00006130U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY                 (0x00006134U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY                 (0x00006138U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY                 (0x0000613CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY                 (0x00006140U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY                 (0x00006144U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY                 (0x00006148U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY                 (0x0000614CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY                 (0x00006150U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY                 (0x00006154U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY                 (0x00006158U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY                 (0x0000615CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY                 (0x00006160U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY                 (0x00006164U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY                 (0x00006168U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY                 (0x0000616CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY                 (0x00006170U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY                 (0x00006174U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY                 (0x00006178U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY                 (0x0000617CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY                 (0x00006180U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY                 (0x00006184U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY                 (0x00006188U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY                 (0x0000618CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY                (0x00006190U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY                (0x00006194U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY                (0x00006198U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY                (0x0000619CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY                (0x000061A0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY                (0x000061A4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY                (0x000061A8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY                (0x000061ACU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY                (0x000061B0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY                (0x000061B4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY                (0x000061B8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY                (0x000061BCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY                (0x000061C0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY                (0x000061C4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY                (0x000061C8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY                (0x000061CCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY                (0x000061D0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY                (0x000061D4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY                (0x000061D8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY                (0x000061DCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY                (0x000061E0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY                (0x000061E4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY                (0x000061E8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY                (0x000061ECU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY                (0x000061F0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY                (0x000061F4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY                (0x000061F8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY                (0x000061FCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY                (0x00006200U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY                (0x00006204U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY                (0x00006208U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY                (0x0000620CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY                (0x00006210U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY                (0x00006214U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY                (0x00006218U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY                (0x0000621CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY                (0x00006220U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY                (0x00006224U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY                (0x00006228U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY                (0x0000622CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY                (0x00006230U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY                (0x00006234U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY                (0x00006238U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY                (0x0000623CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY                (0x00006240U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY                (0x00006244U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY                (0x00006248U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY                (0x0000624CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY                (0x00006250U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY                (0x00006254U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY                (0x00006258U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY                (0x0000625CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY                (0x00006260U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY                (0x00006264U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY                (0x00006268U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY                (0x0000626CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY                (0x00006270U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY                (0x00006274U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY                (0x00006278U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY                (0x0000627CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY                (0x00006280U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY                (0x00006284U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY                (0x00006288U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY                (0x0000628CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY                (0x00006290U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY                (0x00006294U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY                (0x00006298U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY                (0x0000629CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY                (0x000062A0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY                (0x000062A4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY                (0x000062A8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY                (0x000062ACU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY                (0x000062B0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY                (0x000062B4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY                (0x000062B8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY                (0x000062BCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY                (0x000062C0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY                (0x000062C4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY                (0x000062C8U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY                (0x000062CCU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY                (0x000062D0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY                (0x000062D4U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_PROXY                 (0x00007008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_PROXY                 (0x0000700CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0                    (0x00007100U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1                    (0x00007104U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R2                    (0x00007108U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R3                    (0x0000710CU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R4                    (0x00007110U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R5                    (0x00007114U)

/**************************************************************************
* Field Definition Macros
**************************************************************************/


/* PID */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MINOR_MASK                (0x0000003FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MINOR_SHIFT               (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MINOR_MAX                 (0x0000003FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_CUSTOM_MASK               (0x000000C0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_CUSTOM_SHIFT              (0x00000006U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_CUSTOM_MAX                (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MAJOR_MASK                (0x00000700U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MAJOR_SHIFT               (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MAJOR_MAX                 (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MISC_MASK                 (0x0000F800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MISC_SHIFT                (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MISC_MAX                  (0x0000001FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MSB16_MASK                (0xFFFF0000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MSB16_SHIFT               (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PID_MSB16_MAX                 (0x0000FFFFU)

/* MMR_CFG0 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_SPEC_REV_MASK            (0x0000FFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_SPEC_REV_SHIFT           (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_SPEC_REV_MAX             (0x0000FFFFU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_CFG_REV_MASK             (0xFFFF0000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_CFG_REV_SHIFT            (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_CFG_REV_MAX              (0x0000FFFFU)

/* MMR_CFG1 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PARTITIONS_MASK          (0x000000FFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PARTITIONS_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PARTITIONS_MAX           (0x000000FFU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_EN_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_EN_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_EN_MAX             (0x00000001U)

/* LOCK0_KICK0 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_LOCK0_KICK0_MASK      (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_LOCK0_KICK0_SHIFT     (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_LOCK0_KICK0_MAX       (0xFFFFFFFFU)

/* LOCK0_KICK1 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_LOCK0_KICK1_MASK      (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_LOCK0_KICK1_SHIFT     (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_LOCK0_KICK1_MAX       (0xFFFFFFFFU)

/* INTR_RAW_STATUS */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROT_ERR_MASK     (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROT_ERR_SHIFT    (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROT_ERR_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_ADDR_ERR_MASK     (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_ADDR_ERR_SHIFT    (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_ADDR_ERR_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_KICK_ERR_MASK     (0x00000004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_KICK_ERR_SHIFT    (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_KICK_ERR_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ERR_MASK    (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ERR_SHIFT   (0x00000003U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ERR_MAX     (0x00000001U)

/* INTR_ENABLED_STATUS_CLEAR */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROT_ERR_MASK (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROT_ERR_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROT_ERR_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_ADDR_ERR_MASK (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_ADDR_ERR_SHIFT (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_ADDR_ERR_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_KICK_ERR_MASK (0x00000004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_KICK_ERR_SHIFT (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_KICK_ERR_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROXY_ERR_MASK (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROXY_ERR_SHIFT (0x00000003U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROXY_ERR_MAX (0x00000001U)

/* INTR_ENABLE */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROT_ERR_EN_MASK      (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROT_ERR_EN_SHIFT     (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROT_ERR_EN_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_ADDR_ERR_EN_MASK      (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_ADDR_ERR_EN_SHIFT     (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_ADDR_ERR_EN_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_KICK_ERR_EN_MASK      (0x00000004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_KICK_ERR_EN_SHIFT     (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_KICK_ERR_EN_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ERR_EN_MASK     (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ERR_EN_SHIFT    (0x00000003U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ERR_EN_MAX      (0x00000001U)

/* INTR_ENABLE_CLEAR */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROT_ERR_EN_CLR_MASK (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROT_ERR_EN_CLR_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROT_ERR_EN_CLR_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_ADDR_ERR_EN_CLR_MASK (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_ADDR_ERR_EN_CLR_SHIFT (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_ADDR_ERR_EN_CLR_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_KICK_ERR_EN_CLR_MASK (0x00000004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_KICK_ERR_EN_CLR_SHIFT (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_KICK_ERR_EN_CLR_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ERR_EN_CLR_MASK (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ERR_EN_CLR_SHIFT (0x00000003U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ERR_EN_CLR_MAX (0x00000001U)

/* EOI */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_EOI_EOI_VECTOR_MASK               (0x000000FFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_EOI_EOI_VECTOR_SHIFT              (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_EOI_EOI_VECTOR_MAX                (0x000000FFU)

/* FAULT_ADDRESS */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_FAULT_ADDR_MASK     (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_FAULT_ADDR_SHIFT    (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_FAULT_ADDR_MAX      (0xFFFFFFFFU)

/* FAULT_TYPE_STATUS */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_TYPE_MASK (0x0000003FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_TYPE_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_TYPE_MAX  (0x0000003FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_NS_MASK   (0x00000040U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_NS_SHIFT  (0x00000006U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_NS_MAX    (0x00000001U)

/* FAULT_ATTR_STATUS */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_PRIVID_MASK (0x000000FFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_PRIVID_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_PRIVID_MAX (0x000000FFU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_ROUTEID_MASK (0x000FFF00U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_ROUTEID_SHIFT (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_ROUTEID_MAX (0x00000FFFU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_XID_MASK  (0xFFF00000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_XID_SHIFT (0x00000014U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_XID_MAX   (0x00000FFFU)

/* FAULT_CLEAR */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_FAULT_CLR_MASK        (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_FAULT_CLR_SHIFT       (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_FAULT_CLR_MAX         (0x00000001U)

/* CLAIMREG_P0_R0_READONLY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_READONLY_CLAIMREG_P0_R0_READONLY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_READONLY_CLAIMREG_P0_R0_READONLY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_READONLY_CLAIMREG_P0_R0_READONLY_MAX (0xFFFFFFFFU)

/* PID_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MINOR_PROXY_MASK    (0x0000003FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MINOR_PROXY_SHIFT   (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MINOR_PROXY_MAX     (0x0000003FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_CUSTOM_PROXY_MASK   (0x000000C0U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_CUSTOM_PROXY_SHIFT  (0x00000006U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_CUSTOM_PROXY_MAX    (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MAJOR_PROXY_MASK    (0x00000700U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MAJOR_PROXY_SHIFT   (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MAJOR_PROXY_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MISC_PROXY_MASK     (0x0000F800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MISC_PROXY_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MISC_PROXY_MAX      (0x0000001FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MSB16_PROXY_MASK    (0xFFFF0000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MSB16_PROXY_SHIFT   (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MSB16_PROXY_MAX     (0x0000FFFFU)

/* MMR_CFG0_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_SPEC_REV_PROXY_MASK (0x0000FFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_SPEC_REV_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_SPEC_REV_PROXY_MAX (0x0000FFFFU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_CFG_REV_PROXY_MASK (0xFFFF0000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_CFG_REV_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_CFG_REV_PROXY_MAX (0x0000FFFFU)

/* MMR_CFG1_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PARTITIONS_PROXY_MASK (0x000000FFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PARTITIONS_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PARTITIONS_PROXY_MAX (0x000000FFU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PROXY_EN_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PROXY_EN_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PROXY_EN_PROXY_MAX (0x00000001U)

/* LOCK0_KICK0_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_PROXY_LOCK0_KICK0_PROXY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_PROXY_LOCK0_KICK0_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_PROXY_LOCK0_KICK0_PROXY_MAX (0xFFFFFFFFU)

/* LOCK0_KICK1_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_PROXY_LOCK0_KICK1_PROXY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_PROXY_LOCK0_KICK1_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_PROXY_LOCK0_KICK1_PROXY_MAX (0xFFFFFFFFU)

/* INTR_RAW_STATUS_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROT_ERR_PROXY_MASK (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROT_ERR_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROT_ERR_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ADDR_ERR_PROXY_MASK (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ADDR_ERR_PROXY_SHIFT (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ADDR_ERR_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_KICK_ERR_PROXY_MASK (0x00000004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_KICK_ERR_PROXY_SHIFT (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_KICK_ERR_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROXY_ERR_PROXY_MASK (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROXY_ERR_PROXY_SHIFT (0x00000003U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROXY_ERR_PROXY_MAX (0x00000001U)

/* INTR_ENABLED_STATUS_CLEAR_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROT_ERR_PROXY_MASK (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROT_ERR_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROT_ERR_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_ADDR_ERR_PROXY_MASK (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_ADDR_ERR_PROXY_SHIFT (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_ADDR_ERR_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_KICK_ERR_PROXY_MASK (0x00000004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_KICK_ERR_PROXY_SHIFT (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_KICK_ERR_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROXY_ERR_PROXY_MASK (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROXY_ERR_PROXY_SHIFT (0x00000003U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROXY_ERR_PROXY_MAX (0x00000001U)

/* INTR_ENABLE_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROT_ERR_EN_PROXY_MASK (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROT_ERR_EN_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROT_ERR_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ADDR_ERR_EN_PROXY_MASK (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ADDR_ERR_EN_PROXY_SHIFT (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ADDR_ERR_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_KICK_ERR_EN_PROXY_MASK (0x00000004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_KICK_ERR_EN_PROXY_SHIFT (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_KICK_ERR_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROXY_ERR_EN_PROXY_MASK (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROXY_ERR_EN_PROXY_SHIFT (0x00000003U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROXY_ERR_EN_PROXY_MAX (0x00000001U)

/* INTR_ENABLE_CLEAR_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROT_ERR_EN_CLR_PROXY_MASK (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROT_ERR_EN_CLR_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROT_ERR_EN_CLR_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ADDR_ERR_EN_CLR_PROXY_MASK (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ADDR_ERR_EN_CLR_PROXY_SHIFT (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ADDR_ERR_EN_CLR_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_KICK_ERR_EN_CLR_PROXY_MASK (0x00000004U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_KICK_ERR_EN_CLR_PROXY_SHIFT (0x00000002U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_KICK_ERR_EN_CLR_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROXY_ERR_EN_CLR_PROXY_MASK (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROXY_ERR_EN_CLR_PROXY_SHIFT (0x00000003U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROXY_ERR_EN_CLR_PROXY_MAX (0x00000001U)

/* EOI_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_EOI_PROXY_EOI_VECTOR_PROXY_MASK   (0x000000FFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_EOI_PROXY_EOI_VECTOR_PROXY_SHIFT  (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_EOI_PROXY_EOI_VECTOR_PROXY_MAX    (0x000000FFU)

/* FAULT_ADDRESS_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_PROXY_FAULT_ADDR_PROXY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_PROXY_FAULT_ADDR_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_PROXY_FAULT_ADDR_PROXY_MAX (0xFFFFFFFFU)

/* FAULT_TYPE_STATUS_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_TYPE_PROXY_MASK (0x0000003FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_TYPE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_TYPE_PROXY_MAX (0x0000003FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_NS_PROXY_MASK (0x00000040U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_NS_PROXY_SHIFT (0x00000006U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_NS_PROXY_MAX (0x00000001U)

/* FAULT_ATTR_STATUS_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_PRIVID_PROXY_MASK (0x000000FFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_PRIVID_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_PRIVID_PROXY_MAX (0x000000FFU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_ROUTEID_PROXY_MASK (0x000FFF00U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_ROUTEID_PROXY_SHIFT (0x00000008U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_ROUTEID_PROXY_MAX (0x00000FFFU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_XID_PROXY_MASK (0xFFF00000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_XID_PROXY_SHIFT (0x00000014U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_XID_PROXY_MAX (0x00000FFFU)

/* FAULT_CLEAR_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_PROXY_FAULT_CLR_PROXY_MASK (0x00000001U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_PROXY_FAULT_CLR_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_PROXY_FAULT_CLR_PROXY_MAX (0x00000001U)

/* CLAIMREG_P0_R0 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_CLAIMREG_P0_R0_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_CLAIMREG_P0_R0_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_CLAIMREG_P0_R0_MAX (0xFFFFFFFFU)

/* PADCONFIG0 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_MUXMODE_MASK           (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_MUXMODE_MAX            (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_ST_EN_MASK             (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_ST_EN_MAX              (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLUDEN_MASK          (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLUDEN_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_RXACTIVE_MASK          (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_RXACTIVE_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DRV_STR_MASK           (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DRV_STR_MAX            (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_TX_DIS_MASK            (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_TX_DIS_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_LOCK_MASK              (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_LOCK_SHIFT             (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_LOCK_MAX               (0x00000001U)

/* PADCONFIG1 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_MUXMODE_MASK           (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_MUXMODE_MAX            (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_ST_EN_MASK             (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_ST_EN_MAX              (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLUDEN_MASK          (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLUDEN_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_RXACTIVE_MASK          (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_RXACTIVE_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DRV_STR_MASK           (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DRV_STR_MAX            (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_TX_DIS_MASK            (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_TX_DIS_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_LOCK_MASK              (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_LOCK_SHIFT             (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_LOCK_MAX               (0x00000001U)

/* PADCONFIG2 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_MUXMODE_MASK           (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_MUXMODE_MAX            (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_ST_EN_MASK             (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_ST_EN_MAX              (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLUDEN_MASK          (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLUDEN_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_RXACTIVE_MASK          (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_RXACTIVE_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DRV_STR_MASK           (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DRV_STR_MAX            (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_TX_DIS_MASK            (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_TX_DIS_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_LOCK_MASK              (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_LOCK_SHIFT             (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_LOCK_MAX               (0x00000001U)

/* PADCONFIG3 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_MUXMODE_MASK           (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_MUXMODE_MAX            (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_ST_EN_MASK             (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_ST_EN_MAX              (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLUDEN_MASK          (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLUDEN_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_RXACTIVE_MASK          (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_RXACTIVE_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DRV_STR_MASK           (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DRV_STR_MAX            (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_TX_DIS_MASK            (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_TX_DIS_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_LOCK_MASK              (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_LOCK_SHIFT             (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_LOCK_MAX               (0x00000001U)

/* PADCONFIG4 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_MUXMODE_MASK           (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_MUXMODE_MAX            (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_ST_EN_MASK             (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_ST_EN_MAX              (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLUDEN_MASK          (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLUDEN_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_RXACTIVE_MASK          (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_RXACTIVE_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DRV_STR_MASK           (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DRV_STR_MAX            (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_TX_DIS_MASK            (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_TX_DIS_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_LOCK_MASK              (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_LOCK_SHIFT             (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_LOCK_MAX               (0x00000001U)

/* PADCONFIG5 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_MUXMODE_MASK           (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_MUXMODE_MAX            (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_ST_EN_MASK             (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_ST_EN_MAX              (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLUDEN_MASK          (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLUDEN_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_RXACTIVE_MASK          (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_RXACTIVE_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DRV_STR_MASK           (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DRV_STR_MAX            (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_TX_DIS_MASK            (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_TX_DIS_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_LOCK_MASK              (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_LOCK_SHIFT             (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_LOCK_MAX               (0x00000001U)

/* PADCONFIG6 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_MUXMODE_MASK           (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_MUXMODE_MAX            (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_ST_EN_MASK             (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_ST_EN_MAX              (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLUDEN_MASK          (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLUDEN_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_RXACTIVE_MASK          (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_RXACTIVE_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DRV_STR_MASK           (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DRV_STR_MAX            (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_TX_DIS_MASK            (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_TX_DIS_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_LOCK_MASK              (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_LOCK_SHIFT             (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_LOCK_MAX               (0x00000001U)

/* PADCONFIG7 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_MUXMODE_MASK           (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_MUXMODE_MAX            (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_ST_EN_MASK             (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_ST_EN_MAX              (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLUDEN_MASK          (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLUDEN_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_RXACTIVE_MASK          (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_RXACTIVE_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DRV_STR_MASK           (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DRV_STR_MAX            (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_TX_DIS_MASK            (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_TX_DIS_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_LOCK_MASK              (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_LOCK_SHIFT             (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_LOCK_MAX               (0x00000001U)

/* PADCONFIG8 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_MUXMODE_MASK           (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_MUXMODE_MAX            (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_ST_EN_MASK             (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_ST_EN_MAX              (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLUDEN_MASK          (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLUDEN_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_RXACTIVE_MASK          (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_RXACTIVE_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DRV_STR_MASK           (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DRV_STR_MAX            (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_TX_DIS_MASK            (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_TX_DIS_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_LOCK_MASK              (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_LOCK_SHIFT             (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_LOCK_MAX               (0x00000001U)

/* PADCONFIG9 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_MUXMODE_MASK           (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_MUXMODE_MAX            (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_ST_EN_MASK             (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_ST_EN_MAX              (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLUDEN_MASK          (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLUDEN_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_RXACTIVE_MASK          (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_RXACTIVE_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DRV_STR_MASK           (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DRV_STR_MAX            (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_TX_DIS_MASK            (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_TX_DIS_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_LOCK_MASK              (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_LOCK_SHIFT             (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_LOCK_MAX               (0x00000001U)

/* PADCONFIG10 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_LOCK_MAX              (0x00000001U)

/* PADCONFIG11 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_LOCK_MAX              (0x00000001U)

/* PADCONFIG12 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_LOCK_MAX              (0x00000001U)

/* PADCONFIG13 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_LOCK_MAX              (0x00000001U)

/* PADCONFIG14 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_LOCK_MAX              (0x00000001U)

/* PADCONFIG15 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_LOCK_MAX              (0x00000001U)

/* PADCONFIG16 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_LOCK_MAX              (0x00000001U)

/* PADCONFIG17 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_LOCK_MAX              (0x00000001U)

/* PADCONFIG18 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_LOCK_MAX              (0x00000001U)

/* PADCONFIG19 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_LOCK_MAX              (0x00000001U)

/* PADCONFIG20 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_LOCK_MAX              (0x00000001U)

/* PADCONFIG21 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_LOCK_MAX              (0x00000001U)

/* PADCONFIG22 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_LOCK_MAX              (0x00000001U)

/* PADCONFIG23 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_LOCK_MAX              (0x00000001U)

/* PADCONFIG24 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_LOCK_MAX              (0x00000001U)

/* PADCONFIG25 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_LOCK_MAX              (0x00000001U)

/* PADCONFIG26 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_LOCK_MAX              (0x00000001U)

/* PADCONFIG27 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_LOCK_MAX              (0x00000001U)

/* PADCONFIG28 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_LOCK_MAX              (0x00000001U)

/* PADCONFIG29 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_LOCK_MAX              (0x00000001U)

/* PADCONFIG30 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_LOCK_MAX              (0x00000001U)

/* PADCONFIG31 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_LOCK_MAX              (0x00000001U)

/* PADCONFIG32 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_LOCK_MAX              (0x00000001U)

/* PADCONFIG33 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_LOCK_MAX              (0x00000001U)

/* PADCONFIG34 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_LOCK_MAX              (0x00000001U)

/* PADCONFIG35 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_LOCK_MAX              (0x00000001U)

/* PADCONFIG36 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_LOCK_MAX              (0x00000001U)

/* PADCONFIG37 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_LOCK_MAX              (0x00000001U)

/* PADCONFIG38 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_LOCK_MAX              (0x00000001U)

/* PADCONFIG39 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_LOCK_MAX              (0x00000001U)

/* PADCONFIG40 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_LOCK_MAX              (0x00000001U)

/* PADCONFIG41 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_LOCK_MAX              (0x00000001U)

/* PADCONFIG42 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_LOCK_MAX              (0x00000001U)

/* PADCONFIG43 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_LOCK_MAX              (0x00000001U)

/* PADCONFIG44 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_LOCK_MAX              (0x00000001U)

/* PADCONFIG45 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_LOCK_MAX              (0x00000001U)

/* PADCONFIG46 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_LOCK_MAX              (0x00000001U)

/* PADCONFIG47 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_LOCK_MAX              (0x00000001U)

/* PADCONFIG48 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_LOCK_MAX              (0x00000001U)

/* PADCONFIG49 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_LOCK_MAX              (0x00000001U)

/* PADCONFIG50 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_LOCK_MAX              (0x00000001U)

/* PADCONFIG51 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_LOCK_MAX              (0x00000001U)

/* PADCONFIG52 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_LOCK_MAX              (0x00000001U)

/* PADCONFIG53 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_LOCK_MAX              (0x00000001U)

/* PADCONFIG54 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_LOCK_MAX              (0x00000001U)

/* PADCONFIG55 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_LOCK_MAX              (0x00000001U)

/* PADCONFIG56 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_LOCK_MAX              (0x00000001U)

/* PADCONFIG57 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_LOCK_MAX              (0x00000001U)

/* PADCONFIG58 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_LOCK_MAX              (0x00000001U)

/* PADCONFIG59 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_LOCK_MAX              (0x00000001U)

/* PADCONFIG60 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_LOCK_MAX              (0x00000001U)

/* PADCONFIG61 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_LOCK_MAX              (0x00000001U)

/* PADCONFIG62 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_LOCK_MAX              (0x00000001U)

/* PADCONFIG63 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_LOCK_MAX              (0x00000001U)

/* PADCONFIG64 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_LOCK_MAX              (0x00000001U)

/* PADCONFIG65 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_LOCK_MAX              (0x00000001U)

/* PADCONFIG66 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_LOCK_MAX              (0x00000001U)

/* PADCONFIG67 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_LOCK_MAX              (0x00000001U)

/* PADCONFIG68 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_LOCK_MAX              (0x00000001U)

/* PADCONFIG69 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_LOCK_MAX              (0x00000001U)

/* PADCONFIG70 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_LOCK_MAX              (0x00000001U)

/* PADCONFIG71 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_LOCK_MAX              (0x00000001U)

/* PADCONFIG72 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_LOCK_MAX              (0x00000001U)

/* PADCONFIG73 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_LOCK_MAX              (0x00000001U)

/* PADCONFIG74 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_LOCK_MAX              (0x00000001U)

/* PADCONFIG75 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_LOCK_MAX              (0x00000001U)

/* PADCONFIG76 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_LOCK_MAX              (0x00000001U)

/* PADCONFIG77 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_LOCK_MAX              (0x00000001U)

/* PADCONFIG78 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_LOCK_MAX              (0x00000001U)

/* PADCONFIG79 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_LOCK_MAX              (0x00000001U)

/* PADCONFIG80 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_LOCK_MAX              (0x00000001U)

/* PADCONFIG81 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_LOCK_MAX              (0x00000001U)

/* PADCONFIG82 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_LOCK_MAX              (0x00000001U)

/* PADCONFIG83 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_LOCK_MAX              (0x00000001U)

/* PADCONFIG84 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_LOCK_MAX              (0x00000001U)

/* PADCONFIG85 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_LOCK_MAX              (0x00000001U)

/* PADCONFIG86 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_LOCK_MAX              (0x00000001U)

/* PADCONFIG87 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_LOCK_MAX              (0x00000001U)

/* PADCONFIG88 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_LOCK_MAX              (0x00000001U)

/* PADCONFIG89 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_LOCK_MAX              (0x00000001U)

/* PADCONFIG90 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_LOCK_MAX              (0x00000001U)

/* PADCONFIG91 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_LOCK_MAX              (0x00000001U)

/* PADCONFIG92 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_LOCK_MAX              (0x00000001U)

/* PADCONFIG93 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_LOCK_MAX              (0x00000001U)

/* PADCONFIG94 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_LOCK_MAX              (0x00000001U)

/* PADCONFIG95 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_LOCK_MAX              (0x00000001U)

/* PADCONFIG96 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_LOCK_MAX              (0x00000001U)

/* PADCONFIG97 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_LOCK_MAX              (0x00000001U)

/* PADCONFIG98 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_LOCK_MAX              (0x00000001U)

/* PADCONFIG99 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_MUXMODE_MASK          (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_MUXMODE_SHIFT         (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_MUXMODE_MAX           (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_DEBOUNCE_SEL_MASK     (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_DEBOUNCE_SEL_SHIFT    (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_DEBOUNCE_SEL_MAX      (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_ST_EN_MASK            (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_ST_EN_SHIFT           (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_ST_EN_MAX             (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PULLUDEN_MASK         (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PULLUDEN_SHIFT        (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PULLUDEN_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PULLTYPESEL_MASK      (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PULLTYPESEL_SHIFT     (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PULLTYPESEL_MAX       (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_RXACTIVE_MASK         (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_RXACTIVE_SHIFT        (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_RXACTIVE_MAX          (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_DRV_STR_MASK          (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_DRV_STR_SHIFT         (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_DRV_STR_MAX           (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_TX_DIS_MASK           (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_TX_DIS_SHIFT          (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_TX_DIS_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_LOCK_MASK             (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_LOCK_SHIFT            (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_LOCK_MAX              (0x00000001U)

/* PADCONFIG100 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_LOCK_MAX             (0x00000001U)

/* PADCONFIG101 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_LOCK_MAX             (0x00000001U)

/* PADCONFIG102 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_LOCK_MAX             (0x00000001U)

/* PADCONFIG103 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_LOCK_MAX             (0x00000001U)

/* PADCONFIG104 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_LOCK_MAX             (0x00000001U)

/* PADCONFIG105 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_LOCK_MAX             (0x00000001U)

/* PADCONFIG106 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_LOCK_MAX             (0x00000001U)

/* PADCONFIG107 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_LOCK_MAX             (0x00000001U)

/* PADCONFIG108 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_LOCK_MAX             (0x00000001U)

/* PADCONFIG109 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_LOCK_MAX             (0x00000001U)

/* PADCONFIG110 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_LOCK_MAX             (0x00000001U)

/* PADCONFIG111 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_LOCK_MAX             (0x00000001U)

/* PADCONFIG112 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_LOCK_MAX             (0x00000001U)

/* PADCONFIG113 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_LOCK_MAX             (0x00000001U)

/* PADCONFIG114 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_LOCK_MAX             (0x00000001U)

/* PADCONFIG115 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_LOCK_MAX             (0x00000001U)

/* PADCONFIG116 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_LOCK_MAX             (0x00000001U)

/* PADCONFIG117 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_LOCK_MAX             (0x00000001U)

/* PADCONFIG118 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_LOCK_MAX             (0x00000001U)

/* PADCONFIG119 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_LOCK_MAX             (0x00000001U)

/* PADCONFIG120 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_LOCK_MAX             (0x00000001U)

/* PADCONFIG121 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_LOCK_MAX             (0x00000001U)

/* PADCONFIG122 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_LOCK_MAX             (0x00000001U)

/* PADCONFIG123 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_LOCK_MAX             (0x00000001U)

/* PADCONFIG124 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_LOCK_MAX             (0x00000001U)

/* PADCONFIG125 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_LOCK_MAX             (0x00000001U)

/* PADCONFIG126 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_LOCK_MAX             (0x00000001U)

/* PADCONFIG127 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_LOCK_MAX             (0x00000001U)

/* PADCONFIG128 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_LOCK_MAX             (0x00000001U)

/* PADCONFIG129 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_LOCK_MAX             (0x00000001U)

/* PADCONFIG130 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_LOCK_MAX             (0x00000001U)

/* PADCONFIG131 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_LOCK_MAX             (0x00000001U)

/* PADCONFIG132 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_LOCK_MAX             (0x00000001U)

/* PADCONFIG133 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_LOCK_MAX             (0x00000001U)

/* PADCONFIG134 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_LOCK_MAX             (0x00000001U)

/* PADCONFIG135 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_LOCK_MAX             (0x00000001U)

/* PADCONFIG136 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_LOCK_MAX             (0x00000001U)

/* PADCONFIG137 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_LOCK_MAX             (0x00000001U)

/* PADCONFIG138 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_LOCK_MAX             (0x00000001U)

/* PADCONFIG139 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_LOCK_MAX             (0x00000001U)

/* PADCONFIG140 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_LOCK_MAX             (0x00000001U)

/* PADCONFIG141 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_LOCK_MAX             (0x00000001U)

/* PADCONFIG142 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_LOCK_MAX             (0x00000001U)

/* PADCONFIG143 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_LOCK_MAX             (0x00000001U)

/* PADCONFIG144 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_LOCK_MAX             (0x00000001U)

/* PADCONFIG145 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_LOCK_MAX             (0x00000001U)

/* PADCONFIG146 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_LOCK_MAX             (0x00000001U)

/* PADCONFIG147 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_LOCK_MAX             (0x00000001U)

/* PADCONFIG148 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_LOCK_MAX             (0x00000001U)

/* PADCONFIG149 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_LOCK_MAX             (0x00000001U)

/* PADCONFIG150 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_LOCK_MAX             (0x00000001U)

/* PADCONFIG151 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_LOCK_MAX             (0x00000001U)

/* PADCONFIG152 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_LOCK_MAX             (0x00000001U)

/* PADCONFIG153 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_LOCK_MAX             (0x00000001U)

/* PADCONFIG154 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_LOCK_MAX             (0x00000001U)

/* PADCONFIG155 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_LOCK_MAX             (0x00000001U)

/* PADCONFIG156 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_LOCK_MAX             (0x00000001U)

/* PADCONFIG157 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_LOCK_MAX             (0x00000001U)

/* PADCONFIG158 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_LOCK_MAX             (0x00000001U)

/* PADCONFIG159 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_LOCK_MAX             (0x00000001U)

/* PADCONFIG160 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_LOCK_MAX             (0x00000001U)

/* PADCONFIG161 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_LOCK_MAX             (0x00000001U)

/* PADCONFIG162 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_LOCK_MAX             (0x00000001U)

/* PADCONFIG163 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_LOCK_MAX             (0x00000001U)

/* PADCONFIG164 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_LOCK_MAX             (0x00000001U)

/* PADCONFIG165 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_LOCK_MAX             (0x00000001U)

/* PADCONFIG166 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_LOCK_MAX             (0x00000001U)

/* PADCONFIG167 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_LOCK_MAX             (0x00000001U)

/* PADCONFIG168 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_LOCK_MAX             (0x00000001U)

/* PADCONFIG169 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_LOCK_MAX             (0x00000001U)

/* PADCONFIG170 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_LOCK_MAX             (0x00000001U)

/* PADCONFIG171 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_LOCK_MAX             (0x00000001U)

/* PADCONFIG172 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_LOCK_MAX             (0x00000001U)

/* PADCONFIG173 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_LOCK_MAX             (0x00000001U)

/* PADCONFIG174 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_LOCK_MAX             (0x00000001U)

/* PADCONFIG175 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_LOCK_MAX             (0x00000001U)

/* PADCONFIG176 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_LOCK_MAX             (0x00000001U)

/* PADCONFIG177 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_LOCK_MAX             (0x00000001U)

/* PADCONFIG178 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_LOCK_MAX             (0x00000001U)

/* PADCONFIG179 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_LOCK_MAX             (0x00000001U)

/* PADCONFIG180 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_LOCK_MAX             (0x00000001U)

/* PADCONFIG181 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_MUXMODE_MASK         (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_MUXMODE_SHIFT        (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_MUXMODE_MAX          (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_DEBOUNCE_SEL_MASK    (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_DEBOUNCE_SEL_SHIFT   (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_DEBOUNCE_SEL_MAX     (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_ST_EN_MASK           (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_ST_EN_SHIFT          (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_ST_EN_MAX            (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PULLUDEN_MASK        (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PULLUDEN_SHIFT       (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PULLUDEN_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PULLTYPESEL_MASK     (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PULLTYPESEL_SHIFT    (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PULLTYPESEL_MAX      (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_RXACTIVE_MASK        (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_RXACTIVE_SHIFT       (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_RXACTIVE_MAX         (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_DRV_STR_MASK         (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_DRV_STR_SHIFT        (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_DRV_STR_MAX          (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_TX_DIS_MASK          (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_TX_DIS_SHIFT         (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_TX_DIS_MAX           (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_LOCK_MASK            (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_LOCK_SHIFT           (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_LOCK_MAX             (0x00000001U)

/* LOCK1_KICK0 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_LOCK1_KICK0_MASK      (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_LOCK1_KICK0_SHIFT     (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_LOCK1_KICK0_MAX       (0xFFFFFFFFU)

/* LOCK1_KICK1 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_LOCK1_KICK1_MASK      (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_LOCK1_KICK1_SHIFT     (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_LOCK1_KICK1_MAX       (0xFFFFFFFFU)

/* CLAIMREG_P1_R0_READONLY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_READONLY_CLAIMREG_P1_R0_READONLY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_READONLY_CLAIMREG_P1_R0_READONLY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_READONLY_CLAIMREG_P1_R0_READONLY_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R1_READONLY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_READONLY_CLAIMREG_P1_R1_READONLY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_READONLY_CLAIMREG_P1_R1_READONLY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_READONLY_CLAIMREG_P1_R1_READONLY_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R2_READONLY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R2_READONLY_CLAIMREG_P1_R2_READONLY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R2_READONLY_CLAIMREG_P1_R2_READONLY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R2_READONLY_CLAIMREG_P1_R2_READONLY_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R3_READONLY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R3_READONLY_CLAIMREG_P1_R3_READONLY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R3_READONLY_CLAIMREG_P1_R3_READONLY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R3_READONLY_CLAIMREG_P1_R3_READONLY_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R4_READONLY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R4_READONLY_CLAIMREG_P1_R4_READONLY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R4_READONLY_CLAIMREG_P1_R4_READONLY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R4_READONLY_CLAIMREG_P1_R4_READONLY_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R5_READONLY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R5_READONLY_CLAIMREG_P1_R5_READONLY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R5_READONLY_CLAIMREG_P1_R5_READONLY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R5_READONLY_CLAIMREG_P1_R5_READONLY_MAX (0xFFFFFFFFU)

/* PADCONFIG0_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG1_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG2_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG3_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG4_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG5_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG6_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG7_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG8_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG9_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG10_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG11_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG12_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG13_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG14_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG15_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG16_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG17_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG18_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG19_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG20_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG21_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG22_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG23_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG24_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG25_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG26_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG27_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG28_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG29_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG30_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG31_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG32_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG33_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG33_PROXY_PADCONFIG33_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG34_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG34_PROXY_PADCONFIG34_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG35_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG35_PROXY_PADCONFIG35_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG36_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG36_PROXY_PADCONFIG36_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG37_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG37_PROXY_PADCONFIG37_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG38_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG38_PROXY_PADCONFIG38_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG39_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG39_PROXY_PADCONFIG39_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG40_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG40_PROXY_PADCONFIG40_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG41_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG41_PROXY_PADCONFIG41_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG42_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG42_PROXY_PADCONFIG42_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG43_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG43_PROXY_PADCONFIG43_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG44_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG44_PROXY_PADCONFIG44_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG45_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG45_PROXY_PADCONFIG45_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG46_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG46_PROXY_PADCONFIG46_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG47_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG47_PROXY_PADCONFIG47_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG48_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG48_PROXY_PADCONFIG48_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG49_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG49_PROXY_PADCONFIG49_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG50_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG50_PROXY_PADCONFIG50_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG51_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG51_PROXY_PADCONFIG51_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG52_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG52_PROXY_PADCONFIG52_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG53_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG53_PROXY_PADCONFIG53_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG54_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG54_PROXY_PADCONFIG54_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG55_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG55_PROXY_PADCONFIG55_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG56_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG56_PROXY_PADCONFIG56_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG57_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG57_PROXY_PADCONFIG57_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG58_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG58_PROXY_PADCONFIG58_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG59_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG59_PROXY_PADCONFIG59_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG60_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG60_PROXY_PADCONFIG60_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG61_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG61_PROXY_PADCONFIG61_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG62_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG62_PROXY_PADCONFIG62_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG63_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG63_PROXY_PADCONFIG63_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG64_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG64_PROXY_PADCONFIG64_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG65_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG65_PROXY_PADCONFIG65_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG66_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG66_PROXY_PADCONFIG66_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG67_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG67_PROXY_PADCONFIG67_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG68_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG68_PROXY_PADCONFIG68_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG69_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG69_PROXY_PADCONFIG69_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG70_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG70_PROXY_PADCONFIG70_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG71_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG71_PROXY_PADCONFIG71_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG72_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG72_PROXY_PADCONFIG72_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG73_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG73_PROXY_PADCONFIG73_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG74_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG74_PROXY_PADCONFIG74_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG75_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG75_PROXY_PADCONFIG75_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG76_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG76_PROXY_PADCONFIG76_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG77_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG77_PROXY_PADCONFIG77_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG78_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG78_PROXY_PADCONFIG78_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG79_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG79_PROXY_PADCONFIG79_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG80_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG80_PROXY_PADCONFIG80_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG81_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG81_PROXY_PADCONFIG81_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG82_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG82_PROXY_PADCONFIG82_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG83_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG83_PROXY_PADCONFIG83_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG84_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG84_PROXY_PADCONFIG84_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG85_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG85_PROXY_PADCONFIG85_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG86_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG86_PROXY_PADCONFIG86_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG87_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG87_PROXY_PADCONFIG87_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG88_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG88_PROXY_PADCONFIG88_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG89_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG89_PROXY_PADCONFIG89_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG90_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG90_PROXY_PADCONFIG90_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG91_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG91_PROXY_PADCONFIG91_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG92_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG92_PROXY_PADCONFIG92_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG93_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG93_PROXY_PADCONFIG93_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG94_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG94_PROXY_PADCONFIG94_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG95_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG95_PROXY_PADCONFIG95_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG96_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG96_PROXY_PADCONFIG96_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG97_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG97_PROXY_PADCONFIG97_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG98_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG98_PROXY_PADCONFIG98_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG99_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG99_PROXY_PADCONFIG99_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG100_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG100_PROXY_PADCONFIG100_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG101_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG101_PROXY_PADCONFIG101_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG102_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG102_PROXY_PADCONFIG102_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG103_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG103_PROXY_PADCONFIG103_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG104_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG104_PROXY_PADCONFIG104_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG105_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG105_PROXY_PADCONFIG105_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG106_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG106_PROXY_PADCONFIG106_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG107_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG107_PROXY_PADCONFIG107_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG108_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG108_PROXY_PADCONFIG108_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG109_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG109_PROXY_PADCONFIG109_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG110_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG110_PROXY_PADCONFIG110_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG111_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG111_PROXY_PADCONFIG111_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG112_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG112_PROXY_PADCONFIG112_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG113_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG113_PROXY_PADCONFIG113_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG114_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG114_PROXY_PADCONFIG114_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG115_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG115_PROXY_PADCONFIG115_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG116_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG116_PROXY_PADCONFIG116_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG117_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG117_PROXY_PADCONFIG117_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG118_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG118_PROXY_PADCONFIG118_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG119_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG119_PROXY_PADCONFIG119_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG120_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG120_PROXY_PADCONFIG120_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG121_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG121_PROXY_PADCONFIG121_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG122_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG122_PROXY_PADCONFIG122_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG123_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG123_PROXY_PADCONFIG123_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG124_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG124_PROXY_PADCONFIG124_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG125_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG125_PROXY_PADCONFIG125_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG126_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG126_PROXY_PADCONFIG126_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG127_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG127_PROXY_PADCONFIG127_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG128_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG128_PROXY_PADCONFIG128_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG129_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG129_PROXY_PADCONFIG129_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG130_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG130_PROXY_PADCONFIG130_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG131_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG131_PROXY_PADCONFIG131_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG132_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG132_PROXY_PADCONFIG132_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG133_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG133_PROXY_PADCONFIG133_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG134_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG134_PROXY_PADCONFIG134_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG135_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG135_PROXY_PADCONFIG135_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG136_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG136_PROXY_PADCONFIG136_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG137_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG137_PROXY_PADCONFIG137_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG138_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG138_PROXY_PADCONFIG138_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG139_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG139_PROXY_PADCONFIG139_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG140_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG140_PROXY_PADCONFIG140_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG141_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG141_PROXY_PADCONFIG141_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG142_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG142_PROXY_PADCONFIG142_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG143_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG143_PROXY_PADCONFIG143_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG144_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG144_PROXY_PADCONFIG144_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG145_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG145_PROXY_PADCONFIG145_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG146_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG146_PROXY_PADCONFIG146_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG147_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG147_PROXY_PADCONFIG147_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG148_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG148_PROXY_PADCONFIG148_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG149_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG149_PROXY_PADCONFIG149_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG150_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG150_PROXY_PADCONFIG150_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG151_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG151_PROXY_PADCONFIG151_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG152_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG152_PROXY_PADCONFIG152_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG153_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG153_PROXY_PADCONFIG153_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG154_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG154_PROXY_PADCONFIG154_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG155_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG155_PROXY_PADCONFIG155_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG156_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG156_PROXY_PADCONFIG156_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG157_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG157_PROXY_PADCONFIG157_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG158_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG158_PROXY_PADCONFIG158_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG159_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG159_PROXY_PADCONFIG159_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG160_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG160_PROXY_PADCONFIG160_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG161_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG161_PROXY_PADCONFIG161_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG162_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG162_PROXY_PADCONFIG162_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG163_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG163_PROXY_PADCONFIG163_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG164_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG164_PROXY_PADCONFIG164_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG165_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG165_PROXY_PADCONFIG165_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG166_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG166_PROXY_PADCONFIG166_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG167_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG167_PROXY_PADCONFIG167_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG168_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG168_PROXY_PADCONFIG168_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG169_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG169_PROXY_PADCONFIG169_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG170_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG170_PROXY_PADCONFIG170_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG171_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG171_PROXY_PADCONFIG171_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG172_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG172_PROXY_PADCONFIG172_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG173_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG173_PROXY_PADCONFIG173_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG174_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG174_PROXY_PADCONFIG174_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG175_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG175_PROXY_PADCONFIG175_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG176_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG176_PROXY_PADCONFIG176_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG177_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG177_PROXY_PADCONFIG177_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG178_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG178_PROXY_PADCONFIG178_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG179_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG179_PROXY_PADCONFIG179_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG180_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG180_PROXY_PADCONFIG180_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG181_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_PADCONFIG181_PROXY_PADCONFIG181_LOCK_PROXY_MAX (0x00000001U)

/* LOCK1_KICK0_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_PROXY_LOCK1_KICK0_PROXY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_PROXY_LOCK1_KICK0_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_PROXY_LOCK1_KICK0_PROXY_MAX (0xFFFFFFFFU)

/* LOCK1_KICK1_PROXY */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_PROXY_LOCK1_KICK1_PROXY_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_PROXY_LOCK1_KICK1_PROXY_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_PROXY_LOCK1_KICK1_PROXY_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R0 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_CLAIMREG_P1_R0_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_CLAIMREG_P1_R0_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_CLAIMREG_P1_R0_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R1 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_CLAIMREG_P1_R1_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_CLAIMREG_P1_R1_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_CLAIMREG_P1_R1_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R2 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R2_CLAIMREG_P1_R2_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R2_CLAIMREG_P1_R2_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R2_CLAIMREG_P1_R2_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R3 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R3_CLAIMREG_P1_R3_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R3_CLAIMREG_P1_R3_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R3_CLAIMREG_P1_R3_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R4 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R4_CLAIMREG_P1_R4_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R4_CLAIMREG_P1_R4_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R4_CLAIMREG_P1_R4_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R5 */

#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R5_CLAIMREG_P1_R5_MASK (0xFFFFFFFFU)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R5_CLAIMREG_P1_R5_SHIFT (0x00000000U)
#define CSL_MAIN_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R5_CLAIMREG_P1_R5_MAX (0xFFFFFFFFU)

#ifdef __cplusplus
}
#endif
#endif
