/********************************************************************
 * Copyright (C) 2022 Texas Instruments Incorporated.
 *
 *  Redistribution and use in source and binary forms, with or without
 *  modification, are permitted provided that the following conditions
 *  are met:
 *
 *    Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 *
 *    Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the
 *    distribution.
 *
 *    Neither the name of Texas Instruments Incorporated nor the names of
 *    its contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 *
 *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
 *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
 *  A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
 *  OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
 *  SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
 *  LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 *  DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 *  THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 *  (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
 *  OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 *  Name        : cslr_mcu_padcfg_ctrl_mmr.h
*/
#ifndef CSLR_MCU_PADCFG_CTRL_MMR_H_
#define CSLR_MCU_PADCFG_CTRL_MMR_H_

#ifdef __cplusplus
extern "C"
{
#endif
#include <drivers/hw_include/cslr.h>
#include <stdint.h>

/**************************************************************************
* Module Base Offset Values
**************************************************************************/

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_REGS_BASE                          (0x00000000U)


/**************************************************************************
* Hardware Region  : MMRs in region 0
**************************************************************************/


/**************************************************************************
* Register Overlay Structure
**************************************************************************/

typedef struct {
    volatile uint32_t PID;                       /* PID register */
    volatile uint32_t MMR_CFG0;
    volatile uint32_t MMR_CFG1;
    volatile uint8_t  Resv_4104[4092];
    volatile uint32_t LOCK0_KICK0;               /*  - KICK0 component */
    volatile uint32_t LOCK0_KICK1;               /*  - KICK1 component */
    volatile uint32_t INTR_RAW_STATUS;           /* Interrupt Raw Status/Set Register */
    volatile uint32_t INTR_ENABLED_STATUS_CLEAR;   /* Interrupt Enabled Status/Clear register */
    volatile uint32_t INTR_ENABLE;               /* Interrupt Enable register */
    volatile uint32_t INTR_ENABLE_CLEAR;         /* Interrupt Enable Clear register */
    volatile uint32_t EOI;                       /* EOI register */
    volatile uint32_t FAULT_ADDRESS;             /* Fault Address register */
    volatile uint32_t FAULT_TYPE_STATUS;         /* Fault Type Status register */
    volatile uint32_t FAULT_ATTR_STATUS;         /* Fault Attribute Status register */
    volatile uint32_t FAULT_CLEAR;               /* Fault Clear register */
    volatile uint8_t  Resv_4352[204];
    volatile uint32_t CLAIMREG_P0_R0_READONLY;   /* Claim bits for Partition 0 */
    volatile uint8_t  Resv_8192[3836];
    volatile uint32_t PID_PROXY;                 /* PID register */
    volatile uint32_t MMR_CFG0_PROXY;
    volatile uint32_t MMR_CFG1_PROXY;
    volatile uint8_t  Resv_12296[4092];
    volatile uint32_t LOCK0_KICK0_PROXY;         /*  - KICK0 component */
    volatile uint32_t LOCK0_KICK1_PROXY;         /*  - KICK1 component */
    volatile uint32_t INTR_RAW_STATUS_PROXY;     /* Interrupt Raw Status/Set Register */
    volatile uint32_t INTR_ENABLED_STATUS_CLEAR_PROXY;   /* Interrupt Enabled Status/Clear register */
    volatile uint32_t INTR_ENABLE_PROXY;         /* Interrupt Enable register */
    volatile uint32_t INTR_ENABLE_CLEAR_PROXY;   /* Interrupt Enable Clear register */
    volatile uint32_t EOI_PROXY;                 /* EOI register */
    volatile uint32_t FAULT_ADDRESS_PROXY;       /* Fault Address register */
    volatile uint32_t FAULT_TYPE_STATUS_PROXY;   /* Fault Type Status register */
    volatile uint32_t FAULT_ATTR_STATUS_PROXY;   /* Fault Attribute Status register */
    volatile uint32_t FAULT_CLEAR_PROXY;         /* Fault Clear register */
    volatile uint8_t  Resv_12544[204];
    volatile uint32_t CLAIMREG_P0_R0;            /* Claim bits for Partition 0 */
    volatile uint8_t  Resv_16384[3836];
    volatile uint32_t PADCONFIG0;
    volatile uint32_t PADCONFIG1;
    volatile uint32_t PADCONFIG2;
    volatile uint32_t PADCONFIG3;
    volatile uint32_t PADCONFIG4;
    volatile uint32_t PADCONFIG5;
    volatile uint32_t PADCONFIG6;
    volatile uint32_t PADCONFIG7;
    volatile uint32_t PADCONFIG8;
    volatile uint32_t PADCONFIG9;
    volatile uint32_t PADCONFIG10;
    volatile uint32_t PADCONFIG11;
    volatile uint32_t PADCONFIG12;
    volatile uint32_t PADCONFIG13;
    volatile uint32_t PADCONFIG14;
    volatile uint32_t PADCONFIG15;
    volatile uint32_t PADCONFIG16;
    volatile uint32_t PADCONFIG17;
    volatile uint32_t PADCONFIG18;
    volatile uint32_t PADCONFIG19;
    volatile uint32_t PADCONFIG20;
    volatile uint32_t PADCONFIG21;
    volatile uint32_t PADCONFIG22;
    volatile uint32_t PADCONFIG23;
    volatile uint32_t PADCONFIG24;
    volatile uint32_t PADCONFIG25;
    volatile uint32_t PADCONFIG26;
    volatile uint32_t PADCONFIG27;
    volatile uint32_t PADCONFIG28;
    volatile uint32_t PADCONFIG29;
    volatile uint32_t PADCONFIG30;
    volatile uint32_t PADCONFIG31;
    volatile uint32_t PADCONFIG32;
    volatile uint8_t  Resv_20488[3972];
    volatile uint32_t LOCK1_KICK0;               /*  - KICK0 component */
    volatile uint32_t LOCK1_KICK1;               /*  - KICK1 component */
    volatile uint8_t  Resv_20736[240];
    volatile uint32_t CLAIMREG_P1_R0_READONLY;   /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R1_READONLY;   /* Claim bits for Partition 1 */
    volatile uint8_t  Resv_24576[3832];
    volatile uint32_t PADCONFIG0_PROXY;
    volatile uint32_t PADCONFIG1_PROXY;
    volatile uint32_t PADCONFIG2_PROXY;
    volatile uint32_t PADCONFIG3_PROXY;
    volatile uint32_t PADCONFIG4_PROXY;
    volatile uint32_t PADCONFIG5_PROXY;
    volatile uint32_t PADCONFIG6_PROXY;
    volatile uint32_t PADCONFIG7_PROXY;
    volatile uint32_t PADCONFIG8_PROXY;
    volatile uint32_t PADCONFIG9_PROXY;
    volatile uint32_t PADCONFIG10_PROXY;
    volatile uint32_t PADCONFIG11_PROXY;
    volatile uint32_t PADCONFIG12_PROXY;
    volatile uint32_t PADCONFIG13_PROXY;
    volatile uint32_t PADCONFIG14_PROXY;
    volatile uint32_t PADCONFIG15_PROXY;
    volatile uint32_t PADCONFIG16_PROXY;
    volatile uint32_t PADCONFIG17_PROXY;
    volatile uint32_t PADCONFIG18_PROXY;
    volatile uint32_t PADCONFIG19_PROXY;
    volatile uint32_t PADCONFIG20_PROXY;
    volatile uint32_t PADCONFIG21_PROXY;
    volatile uint32_t PADCONFIG22_PROXY;
    volatile uint32_t PADCONFIG23_PROXY;
    volatile uint32_t PADCONFIG24_PROXY;
    volatile uint32_t PADCONFIG25_PROXY;
    volatile uint32_t PADCONFIG26_PROXY;
    volatile uint32_t PADCONFIG27_PROXY;
    volatile uint32_t PADCONFIG28_PROXY;
    volatile uint32_t PADCONFIG29_PROXY;
    volatile uint32_t PADCONFIG30_PROXY;
    volatile uint32_t PADCONFIG31_PROXY;
    volatile uint32_t PADCONFIG32_PROXY;
    volatile uint8_t  Resv_28680[3972];
    volatile uint32_t LOCK1_KICK0_PROXY;         /*  - KICK0 component */
    volatile uint32_t LOCK1_KICK1_PROXY;         /*  - KICK1 component */
    volatile uint8_t  Resv_28928[240];
    volatile uint32_t CLAIMREG_P1_R0;            /* Claim bits for Partition 1 */
    volatile uint32_t CLAIMREG_P1_R1;            /* Claim bits for Partition 1 */
} CSL_mcu_padcfg_ctrl_mmr_cfg0Regs;


/**************************************************************************
* Register Macros
**************************************************************************/

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID                                (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0                           (0x00000004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1                           (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0                        (0x00001008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1                        (0x0000100CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS                    (0x00001010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR          (0x00001014U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE                        (0x00001018U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR                  (0x0000101CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_EOI                                (0x00001020U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS                      (0x00001024U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS                  (0x00001028U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS                  (0x0000102CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR                        (0x00001030U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_READONLY            (0x00001100U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY                          (0x00002000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY                     (0x00002004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY                     (0x00002008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_PROXY                  (0x00003008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_PROXY                  (0x0000300CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY              (0x00003010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY    (0x00003014U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY                  (0x00003018U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY            (0x0000301CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_EOI_PROXY                          (0x00003020U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_PROXY                (0x00003024U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY            (0x00003028U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY            (0x0000302CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_PROXY                  (0x00003030U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0                     (0x00003100U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0                         (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1                         (0x00004004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2                         (0x00004008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3                         (0x0000400CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4                         (0x00004010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5                         (0x00004014U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6                         (0x00004018U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7                         (0x0000401CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8                         (0x00004020U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9                         (0x00004024U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10                        (0x00004028U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11                        (0x0000402CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12                        (0x00004030U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13                        (0x00004034U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14                        (0x00004038U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15                        (0x0000403CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16                        (0x00004040U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17                        (0x00004044U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18                        (0x00004048U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19                        (0x0000404CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20                        (0x00004050U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21                        (0x00004054U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22                        (0x00004058U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23                        (0x0000405CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24                        (0x00004060U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25                        (0x00004064U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26                        (0x00004068U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27                        (0x0000406CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28                        (0x00004070U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29                        (0x00004074U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30                        (0x00004078U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31                        (0x0000407CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32                        (0x00004080U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0                        (0x00005008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1                        (0x0000500CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_READONLY            (0x00005100U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_READONLY            (0x00005104U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY                   (0x00006000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY                   (0x00006004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY                   (0x00006008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY                   (0x0000600CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY                   (0x00006010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY                   (0x00006014U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY                   (0x00006018U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY                   (0x0000601CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY                   (0x00006020U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY                   (0x00006024U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY                  (0x00006028U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY                  (0x0000602CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY                  (0x00006030U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY                  (0x00006034U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY                  (0x00006038U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY                  (0x0000603CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY                  (0x00006040U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY                  (0x00006044U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY                  (0x00006048U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY                  (0x0000604CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY                  (0x00006050U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY                  (0x00006054U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY                  (0x00006058U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY                  (0x0000605CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY                  (0x00006060U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY                  (0x00006064U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY                  (0x00006068U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY                  (0x0000606CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY                  (0x00006070U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY                  (0x00006074U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY                  (0x00006078U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY                  (0x0000607CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY                  (0x00006080U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_PROXY                  (0x00007008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_PROXY                  (0x0000700CU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0                     (0x00007100U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1                     (0x00007104U)

/**************************************************************************
* Field Definition Macros
**************************************************************************/


/* PID */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MINOR_MASK                 (0x0000003FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MINOR_SHIFT                (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MINOR_MAX                  (0x0000003FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_CUSTOM_MASK                (0x000000C0U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_CUSTOM_SHIFT               (0x00000006U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_CUSTOM_MAX                 (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MAJOR_MASK                 (0x00000700U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MAJOR_SHIFT                (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MAJOR_MAX                  (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MISC_MASK                  (0x0000F800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MISC_SHIFT                 (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MISC_MAX                   (0x0000001FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MSB16_MASK                 (0xFFFF0000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MSB16_SHIFT                (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PID_MSB16_MAX                  (0x0000FFFFU)

/* MMR_CFG0 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_SPEC_REV_MASK             (0x0000FFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_SPEC_REV_SHIFT            (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_SPEC_REV_MAX              (0x0000FFFFU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_CFG_REV_MASK              (0xFFFF0000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_CFG_REV_SHIFT             (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_CFG_REV_MAX               (0x0000FFFFU)

/* MMR_CFG1 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PARTITIONS_MASK           (0x000000FFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PARTITIONS_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PARTITIONS_MAX            (0x000000FFU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_EN_MASK             (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_EN_SHIFT            (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_EN_MAX              (0x00000001U)

/* LOCK0_KICK0 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_LOCK0_KICK0_MASK       (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_LOCK0_KICK0_SHIFT      (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_LOCK0_KICK0_MAX        (0xFFFFFFFFU)

/* LOCK0_KICK1 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_LOCK0_KICK1_MASK       (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_LOCK0_KICK1_SHIFT      (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_LOCK0_KICK1_MAX        (0xFFFFFFFFU)

/* INTR_RAW_STATUS */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROT_ERR_MASK      (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROT_ERR_SHIFT     (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROT_ERR_MAX       (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_ADDR_ERR_MASK      (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_ADDR_ERR_SHIFT     (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_ADDR_ERR_MAX       (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_KICK_ERR_MASK      (0x00000004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_KICK_ERR_SHIFT     (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_KICK_ERR_MAX       (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ERR_MASK     (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ERR_SHIFT    (0x00000003U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ERR_MAX      (0x00000001U)

/* INTR_ENABLED_STATUS_CLEAR */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROT_ERR_MASK (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROT_ERR_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROT_ERR_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_ADDR_ERR_MASK (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_ADDR_ERR_SHIFT (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_ADDR_ERR_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_KICK_ERR_MASK (0x00000004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_KICK_ERR_SHIFT (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_KICK_ERR_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROXY_ERR_MASK (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROXY_ERR_SHIFT (0x00000003U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_ENABLED_PROXY_ERR_MAX (0x00000001U)

/* INTR_ENABLE */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROT_ERR_EN_MASK       (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROT_ERR_EN_SHIFT      (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROT_ERR_EN_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_ADDR_ERR_EN_MASK       (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_ADDR_ERR_EN_SHIFT      (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_ADDR_ERR_EN_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_KICK_ERR_EN_MASK       (0x00000004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_KICK_ERR_EN_SHIFT      (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_KICK_ERR_EN_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ERR_EN_MASK      (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ERR_EN_SHIFT     (0x00000003U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ERR_EN_MAX       (0x00000001U)

/* INTR_ENABLE_CLEAR */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROT_ERR_EN_CLR_MASK (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROT_ERR_EN_CLR_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROT_ERR_EN_CLR_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_ADDR_ERR_EN_CLR_MASK (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_ADDR_ERR_EN_CLR_SHIFT (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_ADDR_ERR_EN_CLR_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_KICK_ERR_EN_CLR_MASK (0x00000004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_KICK_ERR_EN_CLR_SHIFT (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_KICK_ERR_EN_CLR_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ERR_EN_CLR_MASK (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ERR_EN_CLR_SHIFT (0x00000003U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ERR_EN_CLR_MAX (0x00000001U)

/* EOI */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_EOI_EOI_VECTOR_MASK                (0x000000FFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_EOI_EOI_VECTOR_SHIFT               (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_EOI_EOI_VECTOR_MAX                 (0x000000FFU)

/* FAULT_ADDRESS */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_FAULT_ADDR_MASK      (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_FAULT_ADDR_SHIFT     (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_FAULT_ADDR_MAX       (0xFFFFFFFFU)

/* FAULT_TYPE_STATUS */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_TYPE_MASK  (0x0000003FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_TYPE_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_TYPE_MAX   (0x0000003FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_NS_MASK    (0x00000040U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_NS_SHIFT   (0x00000006U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_FAULT_NS_MAX     (0x00000001U)

/* FAULT_ATTR_STATUS */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_PRIVID_MASK (0x000000FFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_PRIVID_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_PRIVID_MAX (0x000000FFU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_ROUTEID_MASK (0x000FFF00U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_ROUTEID_SHIFT (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_ROUTEID_MAX (0x00000FFFU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_XID_MASK   (0xFFF00000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_XID_SHIFT  (0x00000014U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_FAULT_XID_MAX    (0x00000FFFU)

/* FAULT_CLEAR */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_FAULT_CLR_MASK         (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_FAULT_CLR_SHIFT        (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_FAULT_CLR_MAX          (0x00000001U)

/* CLAIMREG_P0_R0_READONLY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_READONLY_CLAIMREG_P0_R0_READONLY_MASK (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_READONLY_CLAIMREG_P0_R0_READONLY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_READONLY_CLAIMREG_P0_R0_READONLY_MAX (0xFFFFFFFFU)

/* PID_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MINOR_PROXY_MASK     (0x0000003FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MINOR_PROXY_SHIFT    (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MINOR_PROXY_MAX      (0x0000003FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_CUSTOM_PROXY_MASK    (0x000000C0U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_CUSTOM_PROXY_SHIFT   (0x00000006U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_CUSTOM_PROXY_MAX     (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MAJOR_PROXY_MASK     (0x00000700U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MAJOR_PROXY_SHIFT    (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MAJOR_PROXY_MAX      (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MISC_PROXY_MASK      (0x0000F800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MISC_PROXY_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MISC_PROXY_MAX       (0x0000001FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MSB16_PROXY_MASK     (0xFFFF0000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MSB16_PROXY_SHIFT    (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PID_PROXY_PID_MSB16_PROXY_MAX      (0x0000FFFFU)

/* MMR_CFG0_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_SPEC_REV_PROXY_MASK (0x0000FFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_SPEC_REV_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_SPEC_REV_PROXY_MAX (0x0000FFFFU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_CFG_REV_PROXY_MASK (0xFFFF0000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_CFG_REV_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG0_PROXY_MMR_CFG0_CFG_REV_PROXY_MAX (0x0000FFFFU)

/* MMR_CFG1_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PARTITIONS_PROXY_MASK (0x000000FFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PARTITIONS_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PARTITIONS_PROXY_MAX (0x000000FFU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PROXY_EN_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PROXY_EN_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_MMR_CFG1_PROXY_MMR_CFG1_PROXY_EN_PROXY_MAX (0x00000001U)

/* LOCK0_KICK0_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_PROXY_LOCK0_KICK0_PROXY_MASK (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_PROXY_LOCK0_KICK0_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK0_PROXY_LOCK0_KICK0_PROXY_MAX (0xFFFFFFFFU)

/* LOCK0_KICK1_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_PROXY_LOCK0_KICK1_PROXY_MASK (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_PROXY_LOCK0_KICK1_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK0_KICK1_PROXY_LOCK0_KICK1_PROXY_MAX (0xFFFFFFFFU)

/* INTR_RAW_STATUS_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROT_ERR_PROXY_MASK (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROT_ERR_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROT_ERR_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ADDR_ERR_PROXY_MASK (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ADDR_ERR_PROXY_SHIFT (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_ADDR_ERR_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_KICK_ERR_PROXY_MASK (0x00000004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_KICK_ERR_PROXY_SHIFT (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_KICK_ERR_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROXY_ERR_PROXY_MASK (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROXY_ERR_PROXY_SHIFT (0x00000003U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_RAW_STATUS_PROXY_PROXY_ERR_PROXY_MAX (0x00000001U)

/* INTR_ENABLED_STATUS_CLEAR_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROT_ERR_PROXY_MASK (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROT_ERR_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROT_ERR_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_ADDR_ERR_PROXY_MASK (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_ADDR_ERR_PROXY_SHIFT (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_ADDR_ERR_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_KICK_ERR_PROXY_MASK (0x00000004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_KICK_ERR_PROXY_SHIFT (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_KICK_ERR_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROXY_ERR_PROXY_MASK (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROXY_ERR_PROXY_SHIFT (0x00000003U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLED_STATUS_CLEAR_PROXY_ENABLED_PROXY_ERR_PROXY_MAX (0x00000001U)

/* INTR_ENABLE_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROT_ERR_EN_PROXY_MASK (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROT_ERR_EN_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROT_ERR_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ADDR_ERR_EN_PROXY_MASK (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ADDR_ERR_EN_PROXY_SHIFT (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_ADDR_ERR_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_KICK_ERR_EN_PROXY_MASK (0x00000004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_KICK_ERR_EN_PROXY_SHIFT (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_KICK_ERR_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROXY_ERR_EN_PROXY_MASK (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROXY_ERR_EN_PROXY_SHIFT (0x00000003U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_PROXY_PROXY_ERR_EN_PROXY_MAX (0x00000001U)

/* INTR_ENABLE_CLEAR_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROT_ERR_EN_CLR_PROXY_MASK (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROT_ERR_EN_CLR_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROT_ERR_EN_CLR_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ADDR_ERR_EN_CLR_PROXY_MASK (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ADDR_ERR_EN_CLR_PROXY_SHIFT (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_ADDR_ERR_EN_CLR_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_KICK_ERR_EN_CLR_PROXY_MASK (0x00000004U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_KICK_ERR_EN_CLR_PROXY_SHIFT (0x00000002U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_KICK_ERR_EN_CLR_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROXY_ERR_EN_CLR_PROXY_MASK (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROXY_ERR_EN_CLR_PROXY_SHIFT (0x00000003U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_INTR_ENABLE_CLEAR_PROXY_PROXY_ERR_EN_CLR_PROXY_MAX (0x00000001U)

/* EOI_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_EOI_PROXY_EOI_VECTOR_PROXY_MASK    (0x000000FFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_EOI_PROXY_EOI_VECTOR_PROXY_SHIFT   (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_EOI_PROXY_EOI_VECTOR_PROXY_MAX     (0x000000FFU)

/* FAULT_ADDRESS_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_PROXY_FAULT_ADDR_PROXY_MASK (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_PROXY_FAULT_ADDR_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ADDRESS_PROXY_FAULT_ADDR_PROXY_MAX (0xFFFFFFFFU)

/* FAULT_TYPE_STATUS_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_TYPE_PROXY_MASK (0x0000003FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_TYPE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_TYPE_PROXY_MAX (0x0000003FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_NS_PROXY_MASK (0x00000040U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_NS_PROXY_SHIFT (0x00000006U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_TYPE_STATUS_PROXY_FAULT_NS_PROXY_MAX (0x00000001U)

/* FAULT_ATTR_STATUS_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_PRIVID_PROXY_MASK (0x000000FFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_PRIVID_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_PRIVID_PROXY_MAX (0x000000FFU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_ROUTEID_PROXY_MASK (0x000FFF00U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_ROUTEID_PROXY_SHIFT (0x00000008U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_ROUTEID_PROXY_MAX (0x00000FFFU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_XID_PROXY_MASK (0xFFF00000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_XID_PROXY_SHIFT (0x00000014U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_ATTR_STATUS_PROXY_FAULT_XID_PROXY_MAX (0x00000FFFU)

/* FAULT_CLEAR_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_PROXY_FAULT_CLR_PROXY_MASK (0x00000001U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_PROXY_FAULT_CLR_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_FAULT_CLEAR_PROXY_FAULT_CLR_PROXY_MAX (0x00000001U)

/* CLAIMREG_P0_R0 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_CLAIMREG_P0_R0_MASK (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_CLAIMREG_P0_R0_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P0_R0_CLAIMREG_P0_R0_MAX  (0xFFFFFFFFU)

/* PADCONFIG0 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_MUXMODE_MASK            (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_MUXMODE_SHIFT           (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_MUXMODE_MAX             (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DEBOUNCE_SEL_MASK       (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DEBOUNCE_SEL_SHIFT      (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DEBOUNCE_SEL_MAX        (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_ST_EN_MASK              (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_ST_EN_SHIFT             (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_ST_EN_MAX               (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLUDEN_MASK           (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLUDEN_SHIFT          (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLUDEN_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLTYPESEL_MASK        (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLTYPESEL_SHIFT       (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PULLTYPESEL_MAX         (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_RXACTIVE_MASK           (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_RXACTIVE_SHIFT          (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_RXACTIVE_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DRV_STR_MASK            (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DRV_STR_SHIFT           (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_DRV_STR_MAX             (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_TX_DIS_MASK             (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_TX_DIS_SHIFT            (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_TX_DIS_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_LOCK_MASK               (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_LOCK_SHIFT              (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_LOCK_MAX                (0x00000001U)

/* PADCONFIG1 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_MUXMODE_MASK            (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_MUXMODE_SHIFT           (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_MUXMODE_MAX             (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DEBOUNCE_SEL_MASK       (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DEBOUNCE_SEL_SHIFT      (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DEBOUNCE_SEL_MAX        (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_ST_EN_MASK              (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_ST_EN_SHIFT             (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_ST_EN_MAX               (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLUDEN_MASK           (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLUDEN_SHIFT          (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLUDEN_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLTYPESEL_MASK        (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLTYPESEL_SHIFT       (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PULLTYPESEL_MAX         (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_RXACTIVE_MASK           (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_RXACTIVE_SHIFT          (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_RXACTIVE_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DRV_STR_MASK            (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DRV_STR_SHIFT           (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_DRV_STR_MAX             (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_TX_DIS_MASK             (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_TX_DIS_SHIFT            (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_TX_DIS_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_LOCK_MASK               (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_LOCK_SHIFT              (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_LOCK_MAX                (0x00000001U)

/* PADCONFIG2 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_MUXMODE_MASK            (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_MUXMODE_SHIFT           (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_MUXMODE_MAX             (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DEBOUNCE_SEL_MASK       (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DEBOUNCE_SEL_SHIFT      (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DEBOUNCE_SEL_MAX        (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_ST_EN_MASK              (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_ST_EN_SHIFT             (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_ST_EN_MAX               (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLUDEN_MASK           (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLUDEN_SHIFT          (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLUDEN_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLTYPESEL_MASK        (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLTYPESEL_SHIFT       (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PULLTYPESEL_MAX         (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_RXACTIVE_MASK           (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_RXACTIVE_SHIFT          (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_RXACTIVE_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DRV_STR_MASK            (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DRV_STR_SHIFT           (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_DRV_STR_MAX             (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_TX_DIS_MASK             (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_TX_DIS_SHIFT            (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_TX_DIS_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_LOCK_MASK               (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_LOCK_SHIFT              (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_LOCK_MAX                (0x00000001U)

/* PADCONFIG3 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_MUXMODE_MASK            (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_MUXMODE_SHIFT           (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_MUXMODE_MAX             (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DEBOUNCE_SEL_MASK       (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DEBOUNCE_SEL_SHIFT      (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DEBOUNCE_SEL_MAX        (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_ST_EN_MASK              (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_ST_EN_SHIFT             (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_ST_EN_MAX               (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLUDEN_MASK           (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLUDEN_SHIFT          (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLUDEN_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLTYPESEL_MASK        (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLTYPESEL_SHIFT       (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PULLTYPESEL_MAX         (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_RXACTIVE_MASK           (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_RXACTIVE_SHIFT          (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_RXACTIVE_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DRV_STR_MASK            (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DRV_STR_SHIFT           (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_DRV_STR_MAX             (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_TX_DIS_MASK             (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_TX_DIS_SHIFT            (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_TX_DIS_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_LOCK_MASK               (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_LOCK_SHIFT              (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_LOCK_MAX                (0x00000001U)

/* PADCONFIG4 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_MUXMODE_MASK            (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_MUXMODE_SHIFT           (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_MUXMODE_MAX             (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DEBOUNCE_SEL_MASK       (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DEBOUNCE_SEL_SHIFT      (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DEBOUNCE_SEL_MAX        (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_ST_EN_MASK              (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_ST_EN_SHIFT             (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_ST_EN_MAX               (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLUDEN_MASK           (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLUDEN_SHIFT          (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLUDEN_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLTYPESEL_MASK        (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLTYPESEL_SHIFT       (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PULLTYPESEL_MAX         (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_RXACTIVE_MASK           (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_RXACTIVE_SHIFT          (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_RXACTIVE_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DRV_STR_MASK            (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DRV_STR_SHIFT           (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_DRV_STR_MAX             (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_TX_DIS_MASK             (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_TX_DIS_SHIFT            (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_TX_DIS_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_LOCK_MASK               (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_LOCK_SHIFT              (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_LOCK_MAX                (0x00000001U)

/* PADCONFIG5 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_MUXMODE_MASK            (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_MUXMODE_SHIFT           (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_MUXMODE_MAX             (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DEBOUNCE_SEL_MASK       (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DEBOUNCE_SEL_SHIFT      (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DEBOUNCE_SEL_MAX        (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_ST_EN_MASK              (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_ST_EN_SHIFT             (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_ST_EN_MAX               (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLUDEN_MASK           (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLUDEN_SHIFT          (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLUDEN_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLTYPESEL_MASK        (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLTYPESEL_SHIFT       (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PULLTYPESEL_MAX         (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_RXACTIVE_MASK           (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_RXACTIVE_SHIFT          (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_RXACTIVE_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DRV_STR_MASK            (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DRV_STR_SHIFT           (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_DRV_STR_MAX             (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_TX_DIS_MASK             (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_TX_DIS_SHIFT            (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_TX_DIS_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_LOCK_MASK               (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_LOCK_SHIFT              (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_LOCK_MAX                (0x00000001U)

/* PADCONFIG6 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_MUXMODE_MASK            (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_MUXMODE_SHIFT           (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_MUXMODE_MAX             (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DEBOUNCE_SEL_MASK       (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DEBOUNCE_SEL_SHIFT      (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DEBOUNCE_SEL_MAX        (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_ST_EN_MASK              (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_ST_EN_SHIFT             (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_ST_EN_MAX               (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLUDEN_MASK           (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLUDEN_SHIFT          (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLUDEN_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLTYPESEL_MASK        (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLTYPESEL_SHIFT       (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PULLTYPESEL_MAX         (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_RXACTIVE_MASK           (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_RXACTIVE_SHIFT          (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_RXACTIVE_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DRV_STR_MASK            (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DRV_STR_SHIFT           (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_DRV_STR_MAX             (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_TX_DIS_MASK             (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_TX_DIS_SHIFT            (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_TX_DIS_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_LOCK_MASK               (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_LOCK_SHIFT              (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_LOCK_MAX                (0x00000001U)

/* PADCONFIG7 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_MUXMODE_MASK            (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_MUXMODE_SHIFT           (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_MUXMODE_MAX             (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DEBOUNCE_SEL_MASK       (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DEBOUNCE_SEL_SHIFT      (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DEBOUNCE_SEL_MAX        (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_ST_EN_MASK              (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_ST_EN_SHIFT             (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_ST_EN_MAX               (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLUDEN_MASK           (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLUDEN_SHIFT          (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLUDEN_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLTYPESEL_MASK        (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLTYPESEL_SHIFT       (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PULLTYPESEL_MAX         (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_RXACTIVE_MASK           (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_RXACTIVE_SHIFT          (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_RXACTIVE_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DRV_STR_MASK            (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DRV_STR_SHIFT           (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_DRV_STR_MAX             (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_TX_DIS_MASK             (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_TX_DIS_SHIFT            (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_TX_DIS_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_LOCK_MASK               (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_LOCK_SHIFT              (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_LOCK_MAX                (0x00000001U)

/* PADCONFIG8 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_MUXMODE_MASK            (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_MUXMODE_SHIFT           (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_MUXMODE_MAX             (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DEBOUNCE_SEL_MASK       (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DEBOUNCE_SEL_SHIFT      (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DEBOUNCE_SEL_MAX        (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_ST_EN_MASK              (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_ST_EN_SHIFT             (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_ST_EN_MAX               (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLUDEN_MASK           (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLUDEN_SHIFT          (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLUDEN_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLTYPESEL_MASK        (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLTYPESEL_SHIFT       (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PULLTYPESEL_MAX         (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_RXACTIVE_MASK           (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_RXACTIVE_SHIFT          (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_RXACTIVE_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DRV_STR_MASK            (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DRV_STR_SHIFT           (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_DRV_STR_MAX             (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_TX_DIS_MASK             (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_TX_DIS_SHIFT            (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_TX_DIS_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_LOCK_MASK               (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_LOCK_SHIFT              (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_LOCK_MAX                (0x00000001U)

/* PADCONFIG9 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_MUXMODE_MASK            (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_MUXMODE_SHIFT           (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_MUXMODE_MAX             (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DEBOUNCE_SEL_MASK       (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DEBOUNCE_SEL_SHIFT      (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DEBOUNCE_SEL_MAX        (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_ST_EN_MASK              (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_ST_EN_SHIFT             (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_ST_EN_MAX               (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLUDEN_MASK           (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLUDEN_SHIFT          (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLUDEN_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLTYPESEL_MASK        (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLTYPESEL_SHIFT       (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PULLTYPESEL_MAX         (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_RXACTIVE_MASK           (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_RXACTIVE_SHIFT          (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_RXACTIVE_MAX            (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DRV_STR_MASK            (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DRV_STR_SHIFT           (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_DRV_STR_MAX             (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_TX_DIS_MASK             (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_TX_DIS_SHIFT            (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_TX_DIS_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_LOCK_MASK               (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_LOCK_SHIFT              (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_LOCK_MAX                (0x00000001U)

/* PADCONFIG10 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_LOCK_MAX               (0x00000001U)

/* PADCONFIG11 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_LOCK_MAX               (0x00000001U)

/* PADCONFIG12 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_LOCK_MAX               (0x00000001U)

/* PADCONFIG13 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_LOCK_MAX               (0x00000001U)

/* PADCONFIG14 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_LOCK_MAX               (0x00000001U)

/* PADCONFIG15 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_LOCK_MAX               (0x00000001U)

/* PADCONFIG16 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_LOCK_MAX               (0x00000001U)

/* PADCONFIG17 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_LOCK_MAX               (0x00000001U)

/* PADCONFIG18 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_LOCK_MAX               (0x00000001U)

/* PADCONFIG19 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_LOCK_MAX               (0x00000001U)

/* PADCONFIG20 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_LOCK_MAX               (0x00000001U)

/* PADCONFIG21 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_LOCK_MAX               (0x00000001U)

/* PADCONFIG22 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_LOCK_MAX               (0x00000001U)

/* PADCONFIG23 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_LOCK_MAX               (0x00000001U)

/* PADCONFIG24 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_LOCK_MAX               (0x00000001U)

/* PADCONFIG25 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_LOCK_MAX               (0x00000001U)

/* PADCONFIG26 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_LOCK_MAX               (0x00000001U)

/* PADCONFIG27 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_LOCK_MAX               (0x00000001U)

/* PADCONFIG28 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_LOCK_MAX               (0x00000001U)

/* PADCONFIG29 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_LOCK_MAX               (0x00000001U)

/* PADCONFIG30 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_LOCK_MAX               (0x00000001U)

/* PADCONFIG31 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_LOCK_MAX               (0x00000001U)

/* PADCONFIG32 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_MUXMODE_MASK           (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_MUXMODE_SHIFT          (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_MUXMODE_MAX            (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DEBOUNCE_SEL_MASK      (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DEBOUNCE_SEL_SHIFT     (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DEBOUNCE_SEL_MAX       (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_ST_EN_MASK             (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_ST_EN_SHIFT            (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_ST_EN_MAX              (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLUDEN_MASK          (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLUDEN_SHIFT         (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLUDEN_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLTYPESEL_MASK       (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLTYPESEL_SHIFT      (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PULLTYPESEL_MAX        (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_RXACTIVE_MASK          (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_RXACTIVE_SHIFT         (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_RXACTIVE_MAX           (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DRV_STR_MASK           (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DRV_STR_SHIFT          (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_DRV_STR_MAX            (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_TX_DIS_MASK            (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_TX_DIS_SHIFT           (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_TX_DIS_MAX             (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_LOCK_MASK              (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_LOCK_SHIFT             (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_LOCK_MAX               (0x00000001U)

/* LOCK1_KICK0 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_LOCK1_KICK0_MASK       (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_LOCK1_KICK0_SHIFT      (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_LOCK1_KICK0_MAX        (0xFFFFFFFFU)

/* LOCK1_KICK1 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_LOCK1_KICK1_MASK       (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_LOCK1_KICK1_SHIFT      (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_LOCK1_KICK1_MAX        (0xFFFFFFFFU)

/* CLAIMREG_P1_R0_READONLY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_READONLY_CLAIMREG_P1_R0_READONLY_MASK (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_READONLY_CLAIMREG_P1_R0_READONLY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_READONLY_CLAIMREG_P1_R0_READONLY_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R1_READONLY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_READONLY_CLAIMREG_P1_R1_READONLY_MASK (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_READONLY_CLAIMREG_P1_R1_READONLY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_READONLY_CLAIMREG_P1_R1_READONLY_MAX (0xFFFFFFFFU)

/* PADCONFIG0_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG0_PROXY_PADCONFIG0_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG1_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG1_PROXY_PADCONFIG1_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG2_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG2_PROXY_PADCONFIG2_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG3_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG3_PROXY_PADCONFIG3_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG4_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG4_PROXY_PADCONFIG4_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG5_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG5_PROXY_PADCONFIG5_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG6_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG6_PROXY_PADCONFIG6_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG7_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG7_PROXY_PADCONFIG7_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG8_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG8_PROXY_PADCONFIG8_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG9_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG9_PROXY_PADCONFIG9_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG10_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG10_PROXY_PADCONFIG10_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG11_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG11_PROXY_PADCONFIG11_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG12_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG12_PROXY_PADCONFIG12_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG13_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG13_PROXY_PADCONFIG13_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG14_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG14_PROXY_PADCONFIG14_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG15_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG15_PROXY_PADCONFIG15_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG16_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG16_PROXY_PADCONFIG16_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG17_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG17_PROXY_PADCONFIG17_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG18_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG18_PROXY_PADCONFIG18_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG19_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG19_PROXY_PADCONFIG19_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG20_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG20_PROXY_PADCONFIG20_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG21_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG21_PROXY_PADCONFIG21_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG22_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG22_PROXY_PADCONFIG22_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG23_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG23_PROXY_PADCONFIG23_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG24_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG24_PROXY_PADCONFIG24_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG25_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG25_PROXY_PADCONFIG25_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG26_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG26_PROXY_PADCONFIG26_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG27_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG27_PROXY_PADCONFIG27_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG28_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG28_PROXY_PADCONFIG28_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG29_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG29_PROXY_PADCONFIG29_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG30_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG30_PROXY_PADCONFIG30_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG31_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG31_PROXY_PADCONFIG31_LOCK_PROXY_MAX (0x00000001U)

/* PADCONFIG32_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_MUXMODE_PROXY_MASK (0x0000000FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_MUXMODE_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_MUXMODE_PROXY_MAX (0x0000000FU)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DEBOUNCE_SEL_PROXY_MASK (0x00003800U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DEBOUNCE_SEL_PROXY_SHIFT (0x0000000BU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DEBOUNCE_SEL_PROXY_MAX (0x00000007U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_ST_EN_PROXY_MASK (0x00004000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_ST_EN_PROXY_SHIFT (0x0000000EU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_ST_EN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLUDEN_PROXY_MASK (0x00010000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLUDEN_PROXY_SHIFT (0x00000010U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLUDEN_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLTYPESEL_PROXY_MASK (0x00020000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLTYPESEL_PROXY_SHIFT (0x00000011U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_PULLTYPESEL_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_RXACTIVE_PROXY_MASK (0x00040000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_RXACTIVE_PROXY_SHIFT (0x00000012U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_RXACTIVE_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DRV_STR_PROXY_MASK (0x00180000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DRV_STR_PROXY_SHIFT (0x00000013U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_DRV_STR_PROXY_MAX (0x00000003U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_TX_DIS_PROXY_MASK (0x00200000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_TX_DIS_PROXY_SHIFT (0x00000015U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_TX_DIS_PROXY_MAX (0x00000001U)

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_LOCK_PROXY_MASK (0x80000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_LOCK_PROXY_SHIFT (0x0000001FU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_PADCONFIG32_PROXY_PADCONFIG32_LOCK_PROXY_MAX (0x00000001U)

/* LOCK1_KICK0_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_PROXY_LOCK1_KICK0_PROXY_MASK (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_PROXY_LOCK1_KICK0_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK0_PROXY_LOCK1_KICK0_PROXY_MAX (0xFFFFFFFFU)

/* LOCK1_KICK1_PROXY */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_PROXY_LOCK1_KICK1_PROXY_MASK (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_PROXY_LOCK1_KICK1_PROXY_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_LOCK1_KICK1_PROXY_LOCK1_KICK1_PROXY_MAX (0xFFFFFFFFU)

/* CLAIMREG_P1_R0 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_CLAIMREG_P1_R0_MASK (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_CLAIMREG_P1_R0_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R0_CLAIMREG_P1_R0_MAX  (0xFFFFFFFFU)

/* CLAIMREG_P1_R1 */

#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_CLAIMREG_P1_R1_MASK (0xFFFFFFFFU)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_CLAIMREG_P1_R1_SHIFT (0x00000000U)
#define CSL_MCU_PADCFG_CTRL_MMR_CFG0_CLAIMREG_P1_R1_CLAIMREG_P1_R1_MAX  (0xFFFFFFFFU)

#ifdef __cplusplus
}
#endif
#endif
